/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem B. Blind Problem Solving                               */
/*                                                                */
/* Original idea         Maxim Buzdalov                           */
/* Problem statement     Maxim Buzdalov                           */
/* Test set              Maxim Buzdalov                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Maxim Buzdalov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {
    private static int nTests = 0;
    private static final Random random = new Random(316237);
    private static final File root = new File("tests");
    private static final File lst = new File(root, "tests.lst");

    public static void write(String start, long seed, String caption, int capacity, int... items) {
        //Control the output here.
        if (capacity < 0 || capacity > 1000000000) {
            throw new AssertionError("Capacity is wrong in test " + (nTests + 1) + ": " + capacity);
        }
        for (int i : items) {
            if (i <= 0 || i > 100000000) {
                throw new AssertionError("Item is wrong in test " + (nTests + 1) + ": " + i);
            }
        }
        try {
            PrintWriter lstw = new PrintWriter(new FileWriter(lst, true));
            lstw.printf("%02d: [start = %s] %s%n", nTests + 1, start, caption);
            lstw.close();
        
            PrintWriter out = new PrintWriter(new File(root, String.format("%03d", ++nTests)));
            out.println(items.length + " " + capacity + " " + seed + " " + start);
            for (int i = 0; i < items.length; ++i) {
                if (i != 0) {
                    out.print(" ");
                }
                out.print(items[i]);
            }
            out.println();
            out.close();
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    public static void write(String caption, int capacity, boolean startFromOptimal, int... items) {
        String start = startFromOptimal ? "optimal" : (items.length == 20 || random.nextInt(4) == 0 ? "worst" : "random");
        write(start, random.nextLong(), caption, capacity, items);
    }

    public static void write(String caption, int capacity, int... items) {
        write(caption, capacity, false, items);
    }

    public static void writeHalf(String caption, int... items) {
        int sum = 0;
        for (int i : items) {
            sum += i;
        }
        write(caption, sum / 2, items);
    }

    public static void writeTodd(int n) {
        int k = Integer.numberOfTrailingZeros(n);
        int[] weights = new int[n];
        for (int i = 0; i < n; ++i) {
            weights[i] = (1 << n + k + 1) + (1 << n + k - i) + 1;
        }
        writeHalf("TODD-type test of size " + n, weights);
    }

    public static void writeDegrees(int n) {
        int[] weights = new int[n];
        for (int i = 0; i < n; ++i) {
            weights[i] = 1 << i;
        }
        write("2^i weights of size " + n, random.nextInt(1 << n), weights);
    }

    public static void writeRandom(int n, boolean fromOptimum) {
        int[] weights = new int[n];
        int sum = 0;
        for (int i = 0; i < n; ++i) {
            weights[i] = random.nextInt(100000000) + 1;
            sum += weights[i];
        }
        write("Random test of size " + n, sum / 2, fromOptimum, weights);
    }

    public static void writeSomeEqual(int n, boolean useHalf) {
        int[] weights = new int[n];
        int sum = 0;
        weights[0] = random.nextInt(50000000) + 1;
        for (int i = 1; i < n; ++i) {
            weights[i] = random.nextInt(3) == 0 ? random.nextInt(50000000) + 1 : weights[i - 1];
            sum += weights[i];
        }
        write("Some equal items, N = " + n + ", " + (useHalf ? "C = half sum" : "C = sum - 1"), useHalf ? sum / 2 : sum - 1, weights);
    }

    public static void rm(File file) {
        if (file.isDirectory()) {
            for (File child : file.listFiles()) {
                rm(child);
            }
        }
        file.delete();
    }

    public static void main(String[] args) {
        rm(root);
        root.mkdir();

        write("Sample test", 5, 2, 3);
        write("Simplest test with two items", 3, 2, 1);
        write("Test with C = 0", 0, 1);
        write("C = W_1 = max weight", 100000000, 100000000);
        write("C+1 = W_1 = max weight", 99999999, 100000000);
        write("Simplest tests with choice of 2 from 3", 100000000,  49999999, 5000000, 50000001);
        write("Simple test with equal weights", 1000, 1000, 1000, 1000);

        for (int i = 10; i <= 20; ++i) {
            for (int times = 0; times < 2; ++times) {
                writeDegrees(i);
            }
        }

        for (int i = 10; i <= 20; ++i) {
            writeRandom(i, false);
            writeRandom(i, true);
        }

        for (int i = 10; i <= 20; ++i) {
            writeSomeEqual(i, false);
            writeSomeEqual(i, true);
        }

        for (int i = 10; i <= 20; ++i) {
            writeTodd(i);
        }

        write("worst", 4461863736513623002L, "Anti-blind_mm", 531682630, 31074838, 31074838, 38128411, 38128411, 27270722, 27270722, 27270722, 27270722, 42195893, 42195893, 42195893, 17629031, 17629031, 17629031, 17629031, 17629031, 17629031, 17629031, 23631377, 41645810);
        write("worst", 8465924450017083717L, "Anti-blind_mm", 174215510, 8130204, 8130204, 8130204, 8130204, 8130204, 10557635, 28697954, 28697954, 28697954, 23298840, 937997, 937997, 937997, 3317547, 31638055, 31638055, 31638055, 31638055, 31638055, 31638055);
        write("worst", -8601488522539460225L, "Anti-blind_mm", 425692833, 30653568, 30653568, 30653568, 34748492, 34748492, 34748492, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 17880183, 41431642, 41431642, 41431642, 41431642);
        write("worst", -8135970613158374835L, "Anti-blind_mm", 645855903, 27775332, 27775332, 27775332, 27775332, 27775332, 27775332, 45566210, 45566210, 45566210, 18905472, 16921182, 23429313, 23429313, 36212638, 46417840, 46417840, 46417840, 46417840, 32855668, 32855668);
        write("worst", 3592793357329996770L, "Anti-blind_mm", 465868139, 10420951, 10420951, 24162811, 24162811, 28960603, 28960603, 28960603, 23269896, 23269896, 23269896, 23269896, 33525073, 8032373, 27710244, 27710244, 27710244, 27710244, 27710244, 23525754, 23525754);
        write("worst", 668846662575039425L, "Anti-blind_mm", 69129009, 3375834, 3375834, 4921040, 4921040, 1487694, 1487694, 1487694, 1487694, 26142100, 26142100, 8354381, 8354381, 8354381, 17999015, 17999015, 1148791, 1148791, 1148791, 1148791, 1148791);
        write("worst", 3400576095083003027L, "Anti-blind_mm", 737189536, 34585927, 34585927, 34585927, 40052771, 40052771, 40052771, 46144811, 46144811, 46144811, 46144811, 46144811, 45902256, 45902256, 45902256, 45902256, 45902256, 14203073, 24473654, 24473654, 24473654);
        write("worst", 6277450544592179313L, "Anti-blind_mm", 255477880, 24228976, 20845846, 19101885, 19101885, 4471765, 4471765, 4471765, 49167310, 34983022, 35436626, 35436626, 35436626, 35436626, 34067458, 34067458, 34067458, 41246239, 41246239, 13949581, 13949581);
        write("worst", -3601527284929101773L, "Anti-blind_mm", 184236838, 9181789, 9181789, 21935448, 21935448, 21935448, 21935448, 21935448, 21935448, 18934237, 17236479, 17236479, 11835325, 11835325, 11835325, 11835325, 26912687, 6972753, 1282786, 45881239, 45881239);
        write("worst", 8110138596170951016L, "Anti-blind_mm", 267636151, 17942185, 9088417, 9088417, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 22269815, 22269815, 49225945, 49225945, 49225945, 49225945);
        write("worst", -2958991517969655060L, "Anti-blind_mm", 601856214, 43151774, 43151774, 43151774, 43151774, 36730238, 36730238, 36730238, 36730238, 36730238, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 33293757, 33293757, 33293757);
        write("worst", -7812222152104276933L, "Anti-blind_mm", 229509269, 38108119, 8624044, 14965369, 14965369, 19138215, 17312453, 17312453, 22323045, 22323045, 9787042, 9787042, 9787042, 36180685, 36180685, 36180685, 36180685, 36180685, 36180685, 37804655, 37804655);
        write("worst", -5679603711044037649L, "Anti-blind_mm", 554770653, 33951745, 33951745, 33951745, 33951745, 33951745, 17871949, 30703611, 47001409, 47001409, 47001409, 17637435, 17637435, 17637435, 9288066, 9288066, 9288066, 37151846, 37151846, 37151846, 37151846);
        write("worst", 5531013960822377511L, "Anti-blind_mm", 742101018, 2094970, 35137467, 35137467, 28417301, 29589482, 29589482, 29589482, 29589482, 47520601, 47520601, 47520601, 47520601, 47520601, 47520601, 18661501, 46833876, 46833876, 46833876, 46833876, 33930245);
        write("worst", -1988110500822832030L, "Anti-blind_mm", 167719745, 19318287, 304343, 23990324, 23990324, 40040878, 47921251, 47921251, 44744568, 44744568, 1509173, 1509173, 1509173, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808);
        write("worst", -2753832506023760703L, "Anti-blind_mm", 705849626, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 1347019, 27430125, 27430125, 45988988, 45988988, 45988988, 45988988, 45988988, 45988988);
        write("worst", 588151160134492463L, "Anti-blind_mm", 329364185, 24565309, 24565309, 24565309, 24565309, 24565309, 24565309, 28060206, 41386105, 41386105, 41386105, 20018255, 48420985, 48420985, 48420985, 48420985, 48420985, 48420985, 25625200, 25625200, 21888740);
        write("worst", -7382173903925994449L, "Anti-blind_mm", 302990209, 11015934, 11015934, 11015934, 44007202, 44007202, 44007202, 44007202, 46150123, 46150123, 46150123, 46150123, 46150123, 46150123, 8448269, 20428456, 20428456, 20428456, 20428456, 20428456, 20428456);
        write("worst", -3055670248952288256L, "Anti-blind_mm", 233754468, 16223923, 16223923, 16223923, 16223923, 16223923, 16223923, 3729084, 3729084, 3729084, 3729084, 3729084, 23724702, 23724702, 23724702, 23724702, 23724702, 3841481, 3841481, 3841481, 3841481);
        write("worst", -5592897889285303201L, "Anti-blind_mm", 493803845, 32782796, 32782796, 18154563, 24998978, 24998978, 24998978, 47403944, 47403944, 34453986, 34453986, 34453986, 21463047, 19954154, 19954154, 19954154, 19954154, 19954154, 19954154, 14255868, 14255868);
        write("worst", 5157452807562846650L, "Anti-blind_mm", 499963094, 47730943, 47730943, 47730943, 7557243, 7557243, 18883549, 18883549, 18883549, 18883549, 18883549, 18883549, 38263006, 38263006, 26743561, 26743561, 26743561, 26743561, 12199068, 44011109, 36374996);
        write("worst", -5441318567772091485L, "Anti-blind_mm", 320145509, 27002448, 21415619, 21415619, 21415619, 2365136, 2365136, 2365136, 2365136, 2365136, 47029697, 12881309, 12881309, 12881309, 12881309, 33690316, 33690316, 19534352, 19534352, 19534352, 19534352);
        write("worst", -6734396417318163443L, "Anti-blind_mm", 523434134, 32365712, 32365712, 32365712, 32365712, 32365712, 32365712, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 11946906, 11946906, 11946906, 6355235, 6355235, 6355235);
        write("worst", -838422813915516273L, "Anti-blind_mm", 529679803, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 13749062, 13749062, 13749062, 34667796, 34667796, 40734860, 48048119, 48048119, 48048119, 48048119, 48048119, 48048119);
        write("worst", -2251649545461939725L, "Anti-blind_mm", 399295819, 22617961, 22617961, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 30979279, 30979279, 30979279, 30979279, 18170261, 18170261, 18170261, 18170261, 18170261, 9752014);
        write("worst", -2585592584765854046L, "Anti-blind_mm", 470796283, 48398566, 48398566, 48398566, 48398566, 48398566, 48398566, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 6887733, 6887733, 23796299, 23796299);
        write("worst", 3626552835585586868L, "Anti-blind_mm", 280013023, 43758953, 20453537, 20453537, 20453537, 31513416, 44004711, 35532806, 35532806, 31622797, 48574300, 48574300, 48574300, 48574300, 2642590, 2642590, 24175304, 24175304, 24175304, 24175304, 24175304);
        write("worst", 8816682958231354643L, "Anti-blind_mm", 459733576, 16034642, 21179121, 21179121, 21179121, 28998320, 28998320, 9469488, 9469488, 9469488, 9469488, 47064165, 47064165, 29176461, 29176461, 29176461, 1980275, 46701644, 46701644, 11640173, 11640173);
        write("worst", -2711730819984730783L, "Anti-blind_mm", 392027006, 35099509, 35099509, 35099509, 35099509, 10341044, 10341044, 10341044, 10341044, 10341044, 10341044, 26269032, 26269032, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019);
        write("worst", -409163445790905443L, "Anti-blind_mm", 224132434, 965555, 965555, 965555, 35493986, 204902, 204902, 204902, 204902, 39943395, 39943395, 39943395, 39943395, 29353481, 28190126, 31731275, 31731275, 31731275, 31731275, 31731275, 34046603);
        write("worst", 7268030671733023276L, "Anti-blind_mm", 573173399, 4428284, 4428284, 4428284, 4428284, 32528670, 33775404, 33775404, 33775404, 33775404, 33775404, 38444661, 38444661, 38444661, 38444661, 38444661, 28204722, 28204722, 36616703, 36616703, 36616703);
        write("worst", 1781891944667768580L, "Anti-blind_mm", 516212778, 8110131, 8110131, 8110131, 24038814, 26177289, 26177289, 26177289, 26177289, 26177289, 26177289, 26177289, 40998919, 40998919, 43258926, 49716233, 49716233, 2320863, 2320863, 31690862, 31690862);
        write("worst", -4179883960713179717L, "Anti-blind_mm", 158908732, 46663726, 46663726, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 47867945, 47867945, 41086493, 12477269, 18583362, 44093227, 3801559, 3801559, 19346926, 19346926);
        write("worst", 879766073566401077L, "Anti-blind_mm", 693419501, 20163141, 24379620, 30699683, 30699683, 32347680, 25829080, 25829080, 17047563, 33204260, 45085713, 45085713, 45085713, 45085713, 45085713, 38293059, 43348105, 43348105, 47431236, 43017586, 32516197);
        write("worst", 2012949560768979730L, "Anti-blind_mm", 370098995, 20965912, 20965912, 26513054, 26513054, 26513054, 10011893, 43538981, 43538981, 10053628, 10053628, 10053628, 12522418, 12522418, 8583879, 18119078, 18119078, 18119078, 18119078, 18119078, 18119078);
        write("worst", -6749739465730853896L, "Anti-blind_mm", 415215409, 44726346, 35419082, 11917382, 40844590, 40844590, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 33393701, 33393701, 33393701, 33393701, 33393701, 10575286);
        write("worst", 1436195545463486059L, "Anti-blind_mm", 634706799, 24558241, 24558241, 44557967, 44557967, 23288547, 23288547, 23288547, 23288547, 38365538, 38365538, 38365538, 38365538, 38365538, 38365538, 38365538, 6472533, 6472533, 48791535, 48791535, 48791535);
        write("worst", -8554305864628464260L, "Anti-blind_mm", 242717058, 18006275, 18006275, 18006275, 18006275, 18006275, 18006275, 656732, 656732, 12064793, 31135447, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198);
        write("worst", -683580338631953284L, "Anti-blind_mm", 275214755, 1028346, 6387254, 6387254, 6387254, 6387254, 6387254, 23043629, 23043629, 23043629, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 10224829, 10224829, 10224829);
        write("worst", 3987046643067786362L, "Anti-blind_mm", 651761821, 27891407, 27891407, 42386721, 19751330, 44452986, 44452986, 35797399, 35797399, 32538035, 32538035, 32538035, 34411354, 34411354, 35556718, 45865951, 34684535, 34684535, 34684535, 34684535, 14633972);
        write("worst", 2967611776726053069L, "Anti-blind_mm", 229926609, 7073257, 7073257, 7073257, 7073257, 7073257, 26560707, 26560707, 26560707, 26560707, 26560707, 26560707, 8597918, 14145345, 35636098, 35636098, 35636098, 35636098, 35636098, 35636098, 35636098);
        write("worst", -4619510111231126604L, "Anti-blind_mm", 507162684, 10322380, 10322380, 10322380, 10322380, 9281462, 9281462, 9281462, 9281462, 43567420, 43567420, 43567420, 43567420, 43567420, 43567420, 793470, 33584099, 35821902, 35821902, 35821902, 35821902);
        write("worst", 1179753663900162310L, "Anti-blind_mm", 358533336, 10874640, 10874640, 10874640, 10874640, 10874640, 35760349, 35760349, 35760349, 25288770, 25288770, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 11448648, 38406758);
        write("worst", -3521954202540590956L, "Anti-blind_mm", 192733132, 27989152, 27989152, 27989152, 27989152, 27989152, 26985853, 26985853, 9985255, 9985255, 9985255, 584803, 584803, 584803, 584803, 584803, 37331634, 37331634, 37331634, 37331634, 37331634);
        write("worst", 6513529652742244684L, "Anti-blind_mm", 453285404, 30658210, 30658210, 30658210, 30658210, 30658210, 30658210, 30658210, 4132050, 4132050, 4132050, 4132050, 4132050, 3371802, 3371802, 31344478, 31344478, 31344478, 49299619, 49299619, 49299619);
        write("worst", -1542179911791165086L, "Anti-blind_mm", 531740802, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 48469679, 48469679, 46200317, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356);
        write("worst", 7294468880822098437L, "Anti-blind_mm", 296922312, 279773, 279773, 279773, 47160692, 47160692, 48002633, 48002633, 27510113, 37973593, 25224408, 45716201, 45716201, 36072844, 36546275, 10910486, 29621842, 29621842, 19088834, 19088834, 39866955);
        write("worst", -3003395344458906518L, "Anti-blind_mm", 452777977, 29817756, 29817756, 23004440, 23004440, 15110064, 15110064, 15110064, 15110064, 15110064, 15110064, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 43953063, 43953063);
        write("worst", -5313246493709252998L, "Anti-blind_mm", 236522950, 10834061, 21259344, 38596119, 38596119, 42603313, 34574359, 34574359, 24780286, 24780286, 24780286, 24780286, 24780286, 24780286, 34046692, 46354825, 6751811, 6751811, 6751811, 6751811, 6751811);
        write("worst", -6108610516894981634L, "Anti-blind_mm", 281079657, 30714097, 48182573, 47809500, 47809500, 47809500, 47809500, 47809500, 47809500, 47809500, 17076202, 17076202, 17076202, 17076202, 18251786, 18251786, 18251786, 18251786, 5987684, 5987684, 26022922);
        write("worst", -966377965638515736L, "Anti-blind_mm", 568576236, 47933847, 6618050, 6618050, 40797097, 40797097, 40797097, 40797097, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 25558529);

        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 531682630, 31074838, 31074838, 38128411, 38128411, 27270722, 27270722, 27270722, 27270722, 42195893, 42195893, 42195893, 17629031, 17629031, 17629031, 17629031, 17629031, 17629031, 17629031, 23631377, 41645810);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 174215510, 8130204, 8130204, 8130204, 8130204, 8130204, 10557635, 28697954, 28697954, 28697954, 23298840, 937997, 937997, 937997, 3317547, 31638055, 31638055, 31638055, 31638055, 31638055, 31638055);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 425692833, 30653568, 30653568, 30653568, 34748492, 34748492, 34748492, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 8503719, 17880183, 41431642, 41431642, 41431642, 41431642);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 645855903, 27775332, 27775332, 27775332, 27775332, 27775332, 27775332, 45566210, 45566210, 45566210, 18905472, 16921182, 23429313, 23429313, 36212638, 46417840, 46417840, 46417840, 46417840, 32855668, 32855668);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 465868139, 10420951, 10420951, 24162811, 24162811, 28960603, 28960603, 28960603, 23269896, 23269896, 23269896, 23269896, 33525073, 8032373, 27710244, 27710244, 27710244, 27710244, 27710244, 23525754, 23525754);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 69129009, 3375834, 3375834, 4921040, 4921040, 1487694, 1487694, 1487694, 1487694, 26142100, 26142100, 8354381, 8354381, 8354381, 17999015, 17999015, 1148791, 1148791, 1148791, 1148791, 1148791);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 737189536, 34585927, 34585927, 34585927, 40052771, 40052771, 40052771, 46144811, 46144811, 46144811, 46144811, 46144811, 45902256, 45902256, 45902256, 45902256, 45902256, 14203073, 24473654, 24473654, 24473654);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 255477880, 24228976, 20845846, 19101885, 19101885, 4471765, 4471765, 4471765, 49167310, 34983022, 35436626, 35436626, 35436626, 35436626, 34067458, 34067458, 34067458, 41246239, 41246239, 13949581, 13949581);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 184236838, 9181789, 9181789, 21935448, 21935448, 21935448, 21935448, 21935448, 21935448, 18934237, 17236479, 17236479, 11835325, 11835325, 11835325, 11835325, 26912687, 6972753, 1282786, 45881239, 45881239);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 267636151, 17942185, 9088417, 9088417, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 25059278, 22269815, 22269815, 49225945, 49225945, 49225945, 49225945);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 601856214, 43151774, 43151774, 43151774, 43151774, 36730238, 36730238, 36730238, 36730238, 36730238, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 23608554, 33293757, 33293757, 33293757);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 229509269, 38108119, 8624044, 14965369, 14965369, 19138215, 17312453, 17312453, 22323045, 22323045, 9787042, 9787042, 9787042, 36180685, 36180685, 36180685, 36180685, 36180685, 36180685, 37804655, 37804655);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 554770653, 33951745, 33951745, 33951745, 33951745, 33951745, 17871949, 30703611, 47001409, 47001409, 47001409, 17637435, 17637435, 17637435, 9288066, 9288066, 9288066, 37151846, 37151846, 37151846, 37151846);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 742101018, 2094970, 35137467, 35137467, 28417301, 29589482, 29589482, 29589482, 29589482, 47520601, 47520601, 47520601, 47520601, 47520601, 47520601, 18661501, 46833876, 46833876, 46833876, 46833876, 33930245);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 167719745, 19318287, 304343, 23990324, 23990324, 40040878, 47921251, 47921251, 44744568, 44744568, 1509173, 1509173, 1509173, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808, 7156808);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 705849626, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 37370843, 1347019, 27430125, 27430125, 45988988, 45988988, 45988988, 45988988, 45988988, 45988988);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 329364185, 24565309, 24565309, 24565309, 24565309, 24565309, 24565309, 28060206, 41386105, 41386105, 41386105, 20018255, 48420985, 48420985, 48420985, 48420985, 48420985, 48420985, 25625200, 25625200, 21888740);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 302990209, 11015934, 11015934, 11015934, 44007202, 44007202, 44007202, 44007202, 46150123, 46150123, 46150123, 46150123, 46150123, 46150123, 8448269, 20428456, 20428456, 20428456, 20428456, 20428456, 20428456);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 233754468, 16223923, 16223923, 16223923, 16223923, 16223923, 16223923, 3729084, 3729084, 3729084, 3729084, 3729084, 23724702, 23724702, 23724702, 23724702, 23724702, 3841481, 3841481, 3841481, 3841481);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 493803845, 32782796, 32782796, 18154563, 24998978, 24998978, 24998978, 47403944, 47403944, 34453986, 34453986, 34453986, 21463047, 19954154, 19954154, 19954154, 19954154, 19954154, 19954154, 14255868, 14255868);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 499963094, 47730943, 47730943, 47730943, 7557243, 7557243, 18883549, 18883549, 18883549, 18883549, 18883549, 18883549, 38263006, 38263006, 26743561, 26743561, 26743561, 26743561, 12199068, 44011109, 36374996);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 320145509, 27002448, 21415619, 21415619, 21415619, 2365136, 2365136, 2365136, 2365136, 2365136, 47029697, 12881309, 12881309, 12881309, 12881309, 33690316, 33690316, 19534352, 19534352, 19534352, 19534352);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 523434134, 32365712, 32365712, 32365712, 32365712, 32365712, 32365712, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 38337394, 11946906, 11946906, 11946906, 6355235, 6355235, 6355235);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 529679803, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 12867636, 13749062, 13749062, 13749062, 34667796, 34667796, 40734860, 48048119, 48048119, 48048119, 48048119, 48048119, 48048119);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 399295819, 22617961, 22617961, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 19019678, 30979279, 30979279, 30979279, 30979279, 18170261, 18170261, 18170261, 18170261, 18170261, 9752014);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 470796283, 48398566, 48398566, 48398566, 48398566, 48398566, 48398566, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 16743539, 6887733, 6887733, 23796299, 23796299);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 280013023, 43758953, 20453537, 20453537, 20453537, 31513416, 44004711, 35532806, 35532806, 31622797, 48574300, 48574300, 48574300, 48574300, 2642590, 2642590, 24175304, 24175304, 24175304, 24175304, 24175304);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 459733576, 16034642, 21179121, 21179121, 21179121, 28998320, 28998320, 9469488, 9469488, 9469488, 9469488, 47064165, 47064165, 29176461, 29176461, 29176461, 1980275, 46701644, 46701644, 11640173, 11640173);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 392027006, 35099509, 35099509, 35099509, 35099509, 10341044, 10341044, 10341044, 10341044, 10341044, 10341044, 26269032, 26269032, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019, 21518019);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 224132434, 965555, 965555, 965555, 35493986, 204902, 204902, 204902, 204902, 39943395, 39943395, 39943395, 39943395, 29353481, 28190126, 31731275, 31731275, 31731275, 31731275, 31731275, 34046603);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 573173399, 4428284, 4428284, 4428284, 4428284, 32528670, 33775404, 33775404, 33775404, 33775404, 33775404, 38444661, 38444661, 38444661, 38444661, 38444661, 28204722, 28204722, 36616703, 36616703, 36616703);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 516212778, 8110131, 8110131, 8110131, 24038814, 26177289, 26177289, 26177289, 26177289, 26177289, 26177289, 26177289, 40998919, 40998919, 43258926, 49716233, 49716233, 2320863, 2320863, 31690862, 31690862);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 158908732, 46663726, 46663726, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 1610066, 47867945, 47867945, 41086493, 12477269, 18583362, 44093227, 3801559, 3801559, 19346926, 19346926);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 693419501, 20163141, 24379620, 30699683, 30699683, 32347680, 25829080, 25829080, 17047563, 33204260, 45085713, 45085713, 45085713, 45085713, 45085713, 38293059, 43348105, 43348105, 47431236, 43017586, 32516197);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 370098995, 20965912, 20965912, 26513054, 26513054, 26513054, 10011893, 43538981, 43538981, 10053628, 10053628, 10053628, 12522418, 12522418, 8583879, 18119078, 18119078, 18119078, 18119078, 18119078, 18119078);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 415215409, 44726346, 35419082, 11917382, 40844590, 40844590, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 12071775, 33393701, 33393701, 33393701, 33393701, 33393701, 10575286);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 634706799, 24558241, 24558241, 44557967, 44557967, 23288547, 23288547, 23288547, 23288547, 38365538, 38365538, 38365538, 38365538, 38365538, 38365538, 38365538, 6472533, 6472533, 48791535, 48791535, 48791535);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 242717058, 18006275, 18006275, 18006275, 18006275, 18006275, 18006275, 656732, 656732, 12064793, 31135447, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198, 10817198);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 275214755, 1028346, 6387254, 6387254, 6387254, 6387254, 6387254, 23043629, 23043629, 23043629, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 17934139, 10224829, 10224829, 10224829);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 651761821, 27891407, 27891407, 42386721, 19751330, 44452986, 44452986, 35797399, 35797399, 32538035, 32538035, 32538035, 34411354, 34411354, 35556718, 45865951, 34684535, 34684535, 34684535, 34684535, 14633972);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 229926609, 7073257, 7073257, 7073257, 7073257, 7073257, 26560707, 26560707, 26560707, 26560707, 26560707, 26560707, 8597918, 14145345, 35636098, 35636098, 35636098, 35636098, 35636098, 35636098, 35636098);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 507162684, 10322380, 10322380, 10322380, 10322380, 9281462, 9281462, 9281462, 9281462, 43567420, 43567420, 43567420, 43567420, 43567420, 43567420, 793470, 33584099, 35821902, 35821902, 35821902, 35821902);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 358533336, 10874640, 10874640, 10874640, 10874640, 10874640, 35760349, 35760349, 35760349, 25288770, 25288770, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 13415098, 11448648, 38406758);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 192733132, 27989152, 27989152, 27989152, 27989152, 27989152, 26985853, 26985853, 9985255, 9985255, 9985255, 584803, 584803, 584803, 584803, 584803, 37331634, 37331634, 37331634, 37331634, 37331634);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 453285404, 30658210, 30658210, 30658210, 30658210, 30658210, 30658210, 30658210, 4132050, 4132050, 4132050, 4132050, 4132050, 3371802, 3371802, 31344478, 31344478, 31344478, 49299619, 49299619, 49299619);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 531740802, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 34886785, 48469679, 48469679, 46200317, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356, 13688356);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 296922312, 279773, 279773, 279773, 47160692, 47160692, 48002633, 48002633, 27510113, 37973593, 25224408, 45716201, 45716201, 36072844, 36546275, 10910486, 29621842, 29621842, 19088834, 19088834, 39866955);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 452777977, 29817756, 29817756, 23004440, 23004440, 15110064, 15110064, 15110064, 15110064, 15110064, 15110064, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 24798104, 43953063, 43953063);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 236522950, 10834061, 21259344, 38596119, 38596119, 42603313, 34574359, 34574359, 24780286, 24780286, 24780286, 24780286, 24780286, 24780286, 34046692, 46354825, 6751811, 6751811, 6751811, 6751811, 6751811);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 281079657, 30714097, 48182573, 47809500, 47809500, 47809500, 47809500, 47809500, 47809500, 47809500, 17076202, 17076202, 17076202, 17076202, 18251786, 18251786, 18251786, 18251786, 5987684, 5987684, 26022922);
        write("worst", random.nextLong(), "Anti-blind_mm with random seed", 568576236, 47933847, 6618050, 6618050, 40797097, 40797097, 40797097, 40797097, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 30549435, 25558529);

        //Temporary change
//        for (int times = 0; times < 900; ++times) {
//            writeSomeEqual(20, times % 2 == 0);
//        }
    }
}

