/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem B. Blind Problem Solving                               */
/*                                                                */
/* Original idea         Maxim Buzdalov                           */
/* Problem statement     Maxim Buzdalov                           */
/* Test set              Maxim Buzdalov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 * Solution for NEERC'2012 Problem B: Blind Problem Solving
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class blind_re {

    public static final int MAX_N = 20;
    public static final int MAX_C = 1_000_000_000;
    public static final int MAX_W = 100_000_000;

    public static void main(String[] args) throws Exception {
        new blind_re().go();
    }

    Scanner in;
    PrintWriter out;

    int n;
    int c;
    int curW;

    void go() throws Exception {
        in = new Scanner(System.in);
        out = new PrintWriter(System.out, true); // AUTO-FLUSH !!!
        init();
        solve();
    }

    private void init() {
        n = in.nextInt();
        assert n >= 1 && n <= MAX_N;
        c = in.nextInt();
        assert c >= 0 && c <= MAX_C;
        readCurW();
    }

    private void readCurW() {
        curW = in.nextInt();
        assert curW >= 0 && curW <= MAX_N * MAX_W;
    }

    private void next() {
        in.nextLine();
        readCurW();
    }

    private void decline() {
        out.println("decline");
        next();
    }

    private void accept() {
        out.println("accept");
        next();
    }

    List<Integer> w = new ArrayList<>();
    int solutionBits;
    int solutionWeight;

    private void solve() {
        // go to zero
        int lastW = curW;
        if (curW != 0) {
            decline();
            while (curW != 0) {
                if (curW <= lastW) {
                    lastW = curW;
                    accept();
                } else {
                    decline();
                }
            }
        }
        // accept zero
        lastW = 0;
        accept();
        // go to full solution and figure out all w_i
        while (true) {
            if (curW > lastW) {
                w.add(curW - lastW);
                lastW = curW;
                if (w.size() == n)
                    break; // defer acceptance of full solution until we solve knapsack
                accept();
            } else
                decline();
        }
        for (int wi : w)
            assert wi >= 1 && wi <= MAX_W;
        // solve knapsack
        solveKnapsack();
        // reduce to solution bits
        if (curW != solutionWeight) {
            accept(); // accept full solution (was deferred above)
            int curBits = (1 << n) - 1;
            while (true) {
                if (curW < lastW) {
                    int wi = lastW - curW;
                    boolean found = false;
                    for (int i = 0; i < n; i++) {
                        int bit = 1 << i;
                        if ((curBits & bit) != 0 && (solutionBits & bit) == 0 && w.get(i) == wi) {
                            curBits &= ~bit;
                            found = true;
                            break;
                        }
                    }
                    if (found) {
                        if (curW == solutionWeight)
                            break; // here it is
                        lastW = curW;
                        accept();
                    } else
                        decline();
                } else
                    decline();
            }
        }
        // hurray!
        out.println("stop");
    }

    private void solveKnapsack() {
    bits:
        for (int bits = 0; bits < (1 << n); bits++) {
            int weight = 0;
            for (int i = 0; i < n; i++)
                if ((bits & (1 << i)) != 0) {
                    weight += w.get(i);
                    if (weight > c)
                        continue bits;
                }
            if (weight > solutionWeight) {
                solutionWeight = weight;
                solutionBits = bits;
            }
        }
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(InputStream in) throws FileNotFoundException {
            this.in = new BufferedReader(new InputStreamReader(in));
            nextLine();
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

