/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem C. Caravan Robbers                                     */
/*                                                                */
/* Original idea         Egor Kulikov                             */
/* Problem statement     Egor Kulikov                             */
/* Test set              Egor Kulikov                             */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Maxim Buzdalov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

public class caravan_buzdalov {
    static class Item implements Comparable<Item> {
        public final int s, t;
        public Item(int s, int t) {
            this.s = s;
            this.t = t;
        }
        public int compareTo(Item that) {
            return s - that.s;
        }
    }

    static int gcd(int a, int b) {
        while (b != 0) {
            int tmp = a % b;
            a = b;
            b = tmp;
        }
        return a;
    }

    public static void main(String[] args) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader("caravan.in"));
        int n = Integer.parseInt(in.readLine());
        Item[] items = new Item[n];
        int minLength = 1000000;
        for (int i = 0; i < n; ++i) {
            String ln = in.readLine();
            int ws = ln.indexOf(' ');
            items[i] = new Item(Integer.parseInt(ln.substring(0, ws)), Integer.parseInt(ln.substring(ws + 1)));
            minLength = Math.min(minLength, items[i].t - items[i].s);
        }
        Arrays.sort(items);
        double left = 1, right = minLength;
        for (int it = 0; it < 50; ++it) {
            double mid = (left + right) / 2;

            double last = items[0].s;
            boolean fail = false;
            for (Item i : items) {
                last = Math.max(last, i.s) + mid;
                if (last > i.t + 1e-9) {
                    fail = true;
                    break;
                }
                last = Math.min(last, i.t);
            }
            if (fail) {
                right = mid;
            } else {
                left = mid;
            }
        }

        int optDiv = -1, optNum = -1;

        for (long div = 1; div <= n; ++div) {
            double res = div * left;
            long iv = (long) (res + 0.5);
            if (Math.abs(res - iv) < 1e-4 && gcd((int) div, (int) iv) == 1) {
                long last = items[0].s * div;
                boolean fail = false;
                for (Item i : items) {
                    last = Math.max(last, i.s * div) + iv;
                    if (last > i.t * div) {
                        fail = true;
                        break;
                    }
                }
                if (!fail) {
                    if (optDiv == -1 || optNum * div < optDiv * iv) {
                        optDiv = (int) (div);
                        optNum = (int) (iv);
                    }
                }
            }
        }
        PrintWriter out = new PrintWriter("caravan.out");
        out.println(optNum + "/" + optDiv);
        out.close();
    }
}

