/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem C. Caravan Robbers                                     */
/*                                                                */
/* Original idea         Egor Kulikov                             */
/* Problem statement     Egor Kulikov                             */
/* Test set              Egor Kulikov                             */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.Arrays;

/**
 * Solution for NEERC'2012 Problem C: Caravan Robbers
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class caravan_re {
    public static void main(String[] args) throws Exception {
        new caravan_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    static class Seg implements Comparable<Seg> {
        final int a;
        final int b;

        Seg(int a, int b) {
            this.a = a;
            this.b = b;
        }

        @Override
        public int compareTo(Seg o) {
            return a - o.a;
        }
    }

    int n;
    Seg[] s;

    void read() throws Exception {
        Scanner in = new Scanner(new File("caravan.in"));
        n = in.nextInt();
        assert n >= 1 && n <= 100_000;
        in.nextLine();
        s = new Seg[n];
        for (int i = 0; i < n; i++) {
            int a = in.nextInt();
            int b = in.nextInt();
            assert a >= 0 && a < b && b <= 1_000_000;
            in.nextLine();
            s[i] = new Seg(a, b);
        }
        in.close();
    }

    int[] a;
    int[] b;

    int p;
    int q;

    void solve() {
        // sort & check
        Arrays.sort(s);
        for (int i = 1; i < n; i++)
            assert s[i].a > s[i - 1].a && s[i].b > s[i - 1].b : "old custom";
        // optimize layout
        a = new int[n];
        b = new int[n];
        for (int i = 0; i < n; i++) {
            a[i] = s[i].a;
            b[i] = s[i].b;
        }
        // solve with binary search on fractions with 2^k denominator
        long l = 0; // < min possible integer answer
        long h = (b[n - 1] - a[0]) / n + 1; // > max possible integer answer
        long d = 1;
        // n ~ 10^5
        // n*n ~ 10^10
        // (h-l)' initially ~ 10^6/n
        // at the end of loop values will grow
        //   d ~ n*n*(h-l)' ~ 10^11 (~36 iterations)
        //   h,l ~ (h-l)'*d ~ 10^12
        // we need interval with solution be be smaller than 2x distance between closest fractions
        long eps = 2 * (long) n * n;
        while (compare(h - l, d, 1, eps) > 0) {
            l *= 2;
            h *= 2;
            d *= 2;
            long m = (l + h) / 2; // ~10^12
            long c = 0;
            boolean ok = true;
            // test length m/d, cur position c/d
            for (int i = 0; i < n; i++) {
                c = Math.max(c, a[i] * d) + m;
                if (c > b[i] * d) {
                    ok = false;
                    break;
                }
            }
            if (ok)
                l = m;
            else
                h = m;
        }
        // find closest p/q fraction to m/d where m ~ 10^12, d ~ 10^11
        long m = (l + h) / 2;
        System.out.printf("Found %d/%d ~= %.10f%n", m, d, (double) m / d);
        p = 0;
        q = 1; // at most ~10^5
        for (int qq = 1; qq <= n; qq++) {
            long pp = (qq * m + d / 2) / d; // round to closest pp/qq fraction
            // compare |p/q - m/d| with |pp/qq - m/d|
            long z = Math.abs(p * d - m * q); // z/q
            long zz = Math.abs(pp * d - m * qq); // zz/qq
            if (compare(zz, qq, z, q) < 0) {
                p = (int) pp;
                q = qq;
            }
        }
        // reduce
        int g = gcd(p, q);
        p /= g;
        q /= g;
    }

    long compare(long p1, long q1, long p0, long q0) {
        return p1 * q0 - p0 * q1;
    }

    int gcd(int a, int b) {
        while (b != 0) {
            int r = a % b;
            a = b;
            b = r;
        }
        return a;
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("caravan.out");
        out.println(p + "/" + q);
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

