/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem E. Exact Measurement                                   */
/*                                                                */
/* Original idea         Pavel Mavrin                             */
/* Problem statement     Pavel Mavrin                             */
/* Test set              Pavel Mavrin                             */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Pavel Mavrin                             */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {

    private static int TEST_COUNTER = 0;
    private static final String TESTS_LST = "tests.lst";
    private static final String TESTS_DIR = "tests";
    private static final int MAX_N = 100000;
    private static final long MAX_X = 1000000000000000000L;


    public static void main(String[] args) throws IOException {
        new File(TESTS_DIR).mkdir();
        new Tests().run();
    }

    Random random = new Random(1243464695789890L);

    private void run() throws IOException {
        long[] p10 = new long[19];
        p10[0] = 1;
        for (int i = 1; i < 19; i++) {
            p10[i] = p10[i - 1] * 10;
        }

        printTest(new int[][]{{2, 3}, {1, 5}, {1, 8}, {0, 30}}, 289, "First sample test");
        printTest(new int[][]{{2, 3}, {1, 5}, {1, 7}, {0, 30}}, 300, "Second sample test");
        printTest(new int[][]{{2, 3}}, 201, "Third sample test");

        //Small random tests
        for (int n = 2; n <= 20; n += 2) {
            Box[] boxes = new Box[n];
            int x = 0;
            for (int i = 0; i < n; i++) {
                boxes[i] = new Box(i, random.nextInt(4), random.nextInt(100) + 1);
                x += (1 + random.nextInt((int) boxes[i].q)) * Math.pow(10, boxes[i].k);
            }
            printTest(boxes, x, "Random test, n=" + n);
        }

        //Small random tests with same lengths
        for (int n = 2; n <= 20; n += 2) {
            Box[] boxes = new Box[n];
            int x = 0;
            for (int i = 0; i < n; i++) {
                int k = random.nextInt(4);
                boxes[i] = new Box(i, k, random.nextInt((int) p10[4 - k]) + 1);
                x += (1 + random.nextInt((int) boxes[i].q)) * Math.pow(10, boxes[i].k);
            }
            printTest(boxes, x, "Random test, n=" + n);
        }


        //handmade tests
        printTest(new int[][]{{0, 15}, {0, 15}, {1, 1}, {1, 1}, {1, 1}}, 30, "Handmade test against wrong greedy");
        printTest(new int[][]{{0, 99}, {1, 9}}, 140, "Handmade test against wrong solution");

        //Big random tests
        for (int n = MAX_N * 9 / 10; n <= MAX_N; n += MAX_N / 40) {
            Box[] boxes = new Box[n];
            long x = 0;
            for (int i = 0; i < n; i++) {
                int k = random.nextInt(19);
                long max = Math.min(MAX_X / p10[k], 100);
                boxes[i] = new Box(i, k, (Math.abs(random.nextLong()) % max) + 1);
            }
            x = Math.abs(random.nextLong()) % MAX_X;
            printTest(boxes, x, "Random test, n=" + n);
        }

        //Big random tests with big answer
        long max_v = MAX_X / MAX_N;
        int max_k = 0;
        while (p10[max_k] < max_v) max_k++;

        for (int n = MAX_N * 9 / 10; n <= MAX_N; n += MAX_N / 40) {
            Box[] boxes = new Box[n];
            long x = 0;
            long s = 0;
            for (int i = 0; i < n; i++) {
                int k = random.nextInt(max_k);
                long max = max_v / p10[k];
                boxes[i] = new Box(i, k, (Math.abs(random.nextLong()) % max) + 1);
                s += boxes[i].q * p10[boxes[i].k];
            }
            x = Math.abs(random.nextLong()) % s;
            printTest(boxes, x, "Random test with big answer, n=" + n);
        }

        //Big random tests with big answer
        for (int n = MAX_N * 9 / 10; n <= MAX_N; n += MAX_N / 40) {
            Box[] boxes = new Box[n];
            long x = 0;
            long s = 0;
            for (int i = 0; i < n; i++) {
                int k = random.nextInt(max_k);
                long max = max_v / p10[k];
                boxes[i] = new Box(i, k, (Math.abs(random.nextLong()) % max) + 1);
                s += boxes[i].q * p10[boxes[i].k];
            }
            x = s - random.nextInt(10);
            printTest(boxes, x, "Random test with big answer, n=" + n);
        }

        //Max tests
        {
            int n = MAX_N;
            long x = MAX_X;
            Box[] boxes = new Box[n];
            for (int i = 0; i < n; i++) {
                boxes[i] = new Box(i, 0, x / n);
            }
            printTest(boxes, x, "Max test, a lot of small masses");
        }
        {
            int n = MAX_N;
            long x = MAX_X;
            int k = 0;
            while (p10[k] < (x / n)) k++;
            Box[] boxes = new Box[n];
            for (int i = 0; i < n; i++) {
                boxes[i] = new Box(i, k, 1);
            }
            printTest(boxes, x, "Max test, a lot of medium masses");
        }
        {
            int n = MAX_N;
            long x = MAX_X;
            Box[] boxes = new Box[n];
            for (int i = 0; i < n; i++) {
                boxes[i] = new Box(i, 18, 1);
            }
            printTest(boxes, x, "Max test, a lot of big masses");
        }
    }

    private void printTest(int[][] r, int x, String description) throws IOException {
        Box[] boxes = new Box[r.length];
        for (int i = 0; i < boxes.length; i++) {
            boxes[i] = new Box(i, r[i][0], r[i][1]);
        }
        printTest(boxes, x, description);
    }

    private void printTest(Box[] boxes, long x, String description) throws IOException {
        String tn = String.format("%02d", ++TEST_COUNTER);
        System.out.println(tn + " - " + description);
        PrintWriter lst = new PrintWriter(new FileWriter(TESTS_LST, true));
        lst.println(tn + " " + description);
        lst.close();
        PrintWriter out = new PrintWriter(new FileWriter(new File(TESTS_DIR, tn)));
        out.println(x + " " + boxes.length);
        for (Box box : boxes) {
            out.println(box.k + " " + box.q);
        }
        out.close();
    }

    private List<Box> solve(Box[] boxes, long x) throws IOException {

        long[] nearest = new long[19];
        long z = 1;
        for (int i = 0; i < 19; i++) {
            nearest[i] = (x / z) * z;
            z *= 10;
        }

        PriorityQueue<Box> heap = new PriorityQueue<Box>(boxes.length);
        long sum = 0;

        List<Box> res = new ArrayList<Box>();

        while (sum < x) {
            for (Box box : boxes) {
                if (!box.inHeap && x - sum <= nearest[box.k]) {
                    heap.add(box);
                    box.inHeap = true;
                }
            }
            if (heap.isEmpty()) {
                return null;
            }
            Box longest = heap.remove();
            sum += longest.s;
            res.add(longest);
        }

        return res;
    }

    class Box implements Comparable<Box> {
        int id;
        int k;
        long q;
        long s;
        boolean inHeap;

        Box(int id, int k, long q) {
            this.id = id;
            this.k = k;
            this.q = q;
            s = (q - 1);
            for (int i = 0; i < k; i++) {
                s *= 10;
            }
        }

        @Override
        public int compareTo(Box o) {
            return -Long.compare(s, o.s);
        }
    }

}

