/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem F. Folding Snake Cube                                  */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Roman Elizarov                           */
/* Test set              Roman Elizarov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Georgiy Korneev                          */
/******************************************************************/

import java.io.*;
import java.util.*;

public class folding_gk {
    static Scanner in;
    static PrintWriter out;

    char[] snake;
    char[][][] cube = new char[3][3][3];

    int[] dx = new int[]{1, 0, 0, -1, 0, 0};
    int[] dy = new int[]{0, 1, 0, 0, -1, 0};
    int[] dz = new int[]{0, 0, 1, 0, 0, -1};
    int[][][] next = new int[6][2][];
    int[] turns;

    void run() {
        turns = readSnake();
        System.out.println(Arrays.toString(turns));
        for (int i = 0; i < 6; i++) {
            next[i][0] = new int[]{i};
            next[i][1] = new int[4];
            int c = 0;
            for (int j = 0; j < 6; j++) {
                if (i != j && Math.abs(i - j) != 3) {
                    next[i][1][c++] = j;
                }
            }
        }
        for (int x = 0; x < 3; x++) {
            for (int y = 0; y < 3; y++) {
                for (int z = 0; z < 3; z++) {
                    cube[x][y][z] = snake[0];
                    for (int d = 0; d < 6; d++) {
                        dfs(x, y, z, d, 1);
                    }
                    cube[x][y][z] = 0;
                }
            }
        }
    }

    private void dfs(final int x, final int y, final int z, final int d, int i) {
        if (i == 27) {
            for (char[][] plane : cube) {
                boolean first = true;
                for (char[] row : plane) {
                    if (!first) {
                        out.print(" ");
                    }
                    first = false;
                    out.print(new String(row));
                }
                out.println();
            }
            out.close();
            System.exit(0);
        }
        for (int nd : next[d][turns[i - 1]]) {
            int nx = x + dx[nd];
            int ny = y + dy[nd];
            int nz = z + dz[nd];
            if (0 <= nx && nx < 3 && 0 <= ny && ny < 3 && 0 <= nz && nz < 3 && cube[nx][ny][nz] == 0) {
                cube[nx][ny][nz] = snake[i];
                dfs(nx, ny, nz, nd, i + 1);
                cube[nx][ny][nz] = 0;
            }
        }
    }

    private int[] readSnake() {
        StringBuilder sb = new StringBuilder();
        for (char c = 'A'; c <= 'N'; c++) {
            sb.append(c).append((char) (c ^ ' '));
        }
        snake = sb.toString().substring(0, 27).toCharArray();

        List<String> lines = new ArrayList<>();
        for (int i = 0; i < 15; i++) {
            lines.add(in.next());
        }

        int[] xs = new int[27 + 1];
        int[] ys = new int[27 + 1];
        for (int i = 0; i < 27; i++) {
            for (int y = 0; y < 15; y++) {
                for (int x = 0; x < 15; x++) {
                    if (lines.get(y).charAt(x) == snake[i]) {
                        xs[i + 1] = x + 1;
                        ys[i + 1] = y + 1;
                    }
                }
            }
        }

        int[] turns = new int[26];
        for (int i = 0; i < 26; i++) {
            int dx = xs[i + 2] - xs[i + 1];
            int pdx = xs[i + 1] - xs[i];
            int dy = ys[i + 2] - ys[i + 1];
            int pdy = ys[i + 1] - ys[i];
            turns[i] = dx != pdx || dy != pdy ? 1 : 0;
        }
        turns[0] = 0;
        return turns;
    }

    public static void main(String[] args) throws Exception {
        in = new Scanner(new File("folding.in"));
        out = new PrintWriter("folding.out");

        new folding_gk().run();

        in.close();
        out.close();
    }
}

