/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem F. Folding Snake Cube                                  */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Roman Elizarov                           */
/* Test set              Roman Elizarov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintWriter;

/**
 * Solution for NEERC'2012 Problem F: Folding Snake Cube
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class folding_re {
    private static final int N = 3;
    private static final int N3 = N * N * N;

    private static final int K = 15;

    private static final int[] DX = {1, -1, 0, 0, 0, 0};
    private static final int[] DY = {0, 0, 1, -1, 0, 0};
    private static final int[] DZ = {0, 0, 0, 0, 1, -1};

    public static void main(String[] args) throws Exception {
        long time = System.currentTimeMillis();
        new folding_re().go();
        System.out.println("Completed in " + (System.currentTimeMillis() - time) + " ms");
    }

    void go() throws Exception {
        read();
        resolve();
        solve();
        write();
    }

    char[][] a = new char[K][];
    char[] seq = new char[N3 - 2];
    char[][][] ans = new char[N][N][N];

    void read() throws Exception {
        BufferedReader in = new BufferedReader(new FileReader("folding.in"));
        for (int i = 0; i < K; i++) {
            a[i] = in.readLine().toCharArray();
            assert a[i].length == K : "wrong line length";
            for (int j = 0; j < K; j++) {
                char c = a[i][j];
                assert c == '.' || c >= 'A' && c <= 'N' || c >= 'a' && c <= 'm' : "wrong char";
            }
        }
        assert in.readLine() == null : "extra line";
        in.close();
    }

    void resolve() {
        int x = -1;
        int y = -1;
        char c = code(0);
        start:
        for (x = 0; x < K; x++)
            for (y = 0; y < K; y++)
                if (a[x][y] == c)
                    break start;
        int d = findDir2d(x, y, code(1));
        for (int i = 2; i < N3; i++) {
            x += DX[d];
            y += DY[d];
            int dd = findDir2d(x, y, code(i));
            if (dd == d)
                seq[i - 2] = 'S';
            else
                seq[i - 2] = 'T';
            d = dd;
        }
    }

    int findDir2d(int x, int y, char c) {
        for (int d = 0; d < 4; d++) {
            int xx = x + DX[d];
            int yy = y + DY[d];
            if (xx < 0 || xx >= K || yy < 0 || yy >= K)
                continue;
            if (a[xx][yy] == c)
                return d;
        }
        throw new IllegalArgumentException("Cannot find " + c);
    }

    char code(int i) {
        return i % 2 == 0 ? (char) (i / 2 + 'A') : (char) (i / 2 + 'a');
    }

    void solve() {
        boolean found = false;
        search:
        for (int x = 0; x < (N + 1) / 2; x++)
            for (int y = 0; y <= x; y++)
                for (int z = 0; z <= y; z++) {
                    ans[x][y][z] = code(0);
                    for (int d = 0; d < 6; d++) {
                        if (find(x + DX[d], y + DY[d], z + DZ[d], d, 1)) {
                            found = true;
                            break search;
                        }
                    }
                    ans[x][y][z] = 0;
                }
        assert found;
    }

    boolean find(int x, int y, int z, int d, int i) {
        if (x < 0 || x >= N || y < 0 || y >= N || z < 0 || z >= N)
            return false;
        if (ans[x][y][z] != 0)
            return false;
        ans[x][y][z] = code(i);
        if (i == N3 - 1)
            return true;
        switch (seq[i - 1]) {
            case 'S':
                if (find(x + DX[d], y + DY[d], z + DZ[d], d, i + 1))
                    return true;
                break;
            case 'T':
                int dg = d / 2;
                for (int dd = 0; dd < 6; dd++)
                    if (dd / 2 != dg)
                        if (find(x + DX[dd], y + DY[dd], z + DZ[dd], dd, i + 1))
                            return true;
                break;
            default:
                assert false;
        }
        ans[x][y][z] = 0;
        return false;
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("folding.out");
        for (int x = 0; x < N; x++) {
            for (int y = 0; y < N; y++) {
                if (y > 0)
                    out.print(' ');
                for (int z = 0; z < N; z++)
                    out.print(ans[x][y][z]);
            }
            out.println();
        }
        out.close();
    }
}

