/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem I. Identification of Protein                           */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class identification_petr {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("identification.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("identification.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Identification solver = new Identification();
		solver.solve(1, in, out);
		out.close();
	}

    static class Identification {
        static final long peakP = 9705276;
        static final long peakQ = 12805858;
        static final int MAX_SIZE = 500;
        public void solve(int testNumber, InputReader in, OutputWriter out) {
            int n = in.readInt();
            long[] peaks = new long[n];
            for (int i = 0; i < n; ++i) {
                peaks[i] = Math.round(in.readDouble() * 100000);
            }
            Arrays.sort(peaks);
            int[][] have = new int[MAX_SIZE + 1][MAX_SIZE + 1];
            int mp = 0;
            int mq = 0;
            for (int p = 0; p <= MAX_SIZE; ++p)
                for (int q = 0; p + q <= MAX_SIZE; ++q)
                    if (Arrays.binarySearch(peaks, p * peakP + q * peakQ) >= 0) {
                        have[p][q] = 1;
                        if (p * peakP + q * peakQ > mp * peakP + mq * peakQ) {
                            mp = p;
                            mq = q;
                        }
                    }
            int[][] nhave = new int[mp + 1][mq + 1];
            for (int p = 0; p <= mp; ++p)
                for (int q = 0; q <= mq; ++q) {
                    nhave[p][q] = have[p][q];
                    if (p != mp - p || q != mq - q)
                        nhave[p][q] += have[mp - p][mq - q];
                }
            int steps = (mp + mq) / 2;
            byte[][][] prev = new byte[steps + 1][][];
            int[][] best = new int[1][1];
            for (int step = 0; step <= steps; ++step) {
                prev[step] = new byte[step + 2][step + 2];
                int[][] nbest = new int[step + 2][step + 2];
                for (int[] x : nbest) Arrays.fill(x, -1);
                for (int cl = 0; cl <= step; ++cl)
                    for (int cr = 0; cr <= step; ++cr) {
                        int nl = cl;
                        int nr = cr;
                        int bonus = 0;
                        if (nl <= mp && step - nl <= mq) bonus += nhave[nl][step - nl];
                        if (nl != nr && step * 2 != mp + mq) {
                            if (nr <= mp && step - nr <= mq)
                                bonus += nhave[nr][step - nr];
                        }
                        best[cl][cr] += bonus;
                        if (step < steps)
                            for (int sl = 0; sl < 2; ++sl)
                                for (int sr = 0; sr < 2; ++sr) {
                                    nl = cl + sl;
                                    nr = cr + sr;
                                    if (nbest[nl][nr] < best[cl][cr]) {
                                        nbest[nl][nr] = best[cl][cr];
                                        prev[step][nl][nr] = (byte) (sl * 2 + sr);
                                    }
                                }
                    }
                if (step < steps) best = nbest;
            }
            int resAns = -1;
            int rcl = -1;
            int rcr = -1;
            String extra = "";
            for (int cl = 0; cl <= steps; ++cl)
                for (int cr = 0; cr <= steps; ++cr) {
                    int dl = steps - cl;
                    int dr = steps - cr;
                    if (cl + cr <= mp && dl + dr <= mq) {
                        if (best[cl][cr] > resAns) {
                            resAns = best[cl][cr];
                            rcl = cl;
                            rcr = cr;
                            if (cl + cr < mp) extra = "P"; else if (dl + dr < mq) extra = "Q"; else extra = "";
                        }
                    }
                }
            {
                //System.err.println(resAns);
                String prefix = "";
                String suffix = "";
                for (int step = steps - 1; step >= 0; --step) {
                    int by = prev[step][rcl][rcr];
                    if (by / 2 > 0) {
                        prefix = "P" + prefix;
                        --rcl;
                    } else {
                        prefix = "Q" + prefix;
                    }
                    if (by % 2 > 0) {
                        suffix += "P";
                        --rcr;
                    } else {
                        suffix += "Q";
                    }
                }
                out.printLine(prefix + extra + suffix);
            }
        }
    }

    static class InputReader {

        private InputStream stream;
        private byte[] buf = new byte[1024];
        private int curChar;
        private int numChars;
        private SpaceCharFilter filter;

        public InputReader(InputStream stream) {
            this.stream = stream;
        }

        public int read() {
            if (numChars == -1)
                throw new InputMismatchException();
            if (curChar >= numChars) {
                curChar = 0;
                try {
                    numChars = stream.read(buf);
                } catch (IOException e) {
                    throw new InputMismatchException();
                }
                if (numChars <= 0)
                    return -1;
            }
            return buf[curChar++];
        }

        public int readInt() {
            int c = read();
            while (isSpaceChar(c))
                c = read();
            int sgn = 1;
            if (c == '-') {
                sgn = -1;
                c = read();
            }
            int res = 0;
            do {
                if (c < '0' || c > '9')
                    throw new InputMismatchException();
                res *= 10;
                res += c - '0';
                c = read();
            } while (!isSpaceChar(c));
            return res * sgn;
        }

        public boolean isSpaceChar(int c) {
            if (filter != null)
                return filter.isSpaceChar(c);
            return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
        }

        public double readDouble() {
            int c = read();
            while (isSpaceChar(c))
                c = read();
            int sgn = 1;
            if (c == '-') {
                sgn = -1;
                c = read();
            }
            double res = 0;
            while (!isSpaceChar(c) && c != '.') {
                if (c == 'e' || c == 'E')
                    return res * Math.pow(10, readInt());
                if (c < '0' || c > '9')
                    throw new InputMismatchException();
                res *= 10;
                res += c - '0';
                c = read();
            }
            if (c == '.') {
                c = read();
                double m = 1;
                while (!isSpaceChar(c)) {
                    if (c == 'e' || c == 'E')
                        return res * Math.pow(10, readInt());
                    if (c < '0' || c > '9')
                        throw new InputMismatchException();
                    m /= 10;
                    res += (c - '0') * m;
                    c = read();
                }
            }
            return res * sgn;
        }

        public interface SpaceCharFilter {
            public boolean isSpaceChar(int ch);
        }
    }

    static class OutputWriter {
        private final PrintWriter writer;

        public OutputWriter(OutputStream outputStream) {
            writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
        }

        public OutputWriter(Writer writer) {
            this.writer = new PrintWriter(writer);
        }

        public void print(Object...objects) {
            for (int i = 0; i < objects.length; i++) {
                if (i != 0)
                    writer.print(' ');
                writer.print(objects[i]);
            }
        }

        public void printLine(Object...objects) {
            print(objects);
            writer.println();
        }

        public void close() {
            writer.close();
        }

    }

}


