/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem K. Kingdom Reunion                                     */
/*                                                                */
/* Original idea         Maxim Buzdalov                           */
/* Problem statement     Maxim Buzdalov                           */
/* Test set              Maxim Buzdalov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Maxim Buzdalov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

public class kingdom_buzdalov {
    static long time = System.currentTimeMillis();
    static boolean shouldExit = true;

    static void quit(String message) {
        if (shouldExit) {
            System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
        }
        try {
            PrintWriter out = new PrintWriter("kingdom.out");
            out.println(message);
            out.close();
            if (shouldExit) {
                System.exit(0);
            } else {
                Point.uniq.clear();
                Segment.uniq.clear();
                throw new RuntimeException("42");
            }
        } catch (IOException ex) {}
    }

    static void quitNotAPolygon(String name) { quit(name + " is not a polygon"); }
    static void quitIntersect()              { quit("Aastria and Abstria intersect"); }
    static void quitNotUnion()               { quit("The union of Aastria and Abstria is not equal to Aabstria"); }
    static void quitOk()                     { quit("OK"); }

    public static void main(String[] args) throws IOException {
        BufferedReader in = new BufferedReader(new FileReader("kingdom.in"));
        Point[] a = readPoints(in);
        Point[] b = readPoints(in);
        Point[] ab = readPoints(in);

        throwIfCoinciding(a);
        throwIfCoinciding(b);
        throwIfCoinciding(ab);

        long ssqA = square(a);
        long ssqB = square(b);
        long ssqAB = square(ab);
        long sqA = Math.abs(ssqA);
        long sqB = Math.abs(ssqB);
        long sqAB = Math.abs(ssqAB);

        Point[] all = Point.all();
        Point[] as = a.clone();
        Point[] bs = b.clone();
        Point[] abs = ab.clone();
        Arrays.sort(all);
        Arrays.sort(as);
        Arrays.sort(bs);
        Arrays.sort(abs);
        Segment[] sa = segmentsFromPoints(a, 0, ssqA > 0);
        Segment[] sb = segmentsFromPoints(b, 1, ssqB > 0);
        Segment[] sab = segmentsFromPoints(ab, 2, ssqAB > 0);
        List<Segment> ea = subdivide(sa, subtract(all, as), a);
        List<Segment> eb = subdivide(sb, subtract(all, bs), b);
        List<Segment> eab = subdivide(sab, subtract(all, abs), ab);

        if (ea == null  || sqA == 0)  { quitNotAPolygon("Aastria");  }
        if (eb == null  || sqB == 0)  { quitNotAPolygon("Abstria");  }
        if (eab == null || sqAB == 0) { quitNotAPolygon("Aabstria"); }

        Set<Segment> eA_B = new HashSet<Segment>(ea);
        eA_B.addAll(eb);
        if (subdivide(eA_B.toArray(new Segment[eA_B.size()]), new Point[0], new Point[0]) == null) {
            quitIntersect();
        }

        if (!checkSquareIntersection(ea, eb)) {
            quitIntersect();
        }

        for (Segment e : ea)  { e.mask |= 1; }
        for (Segment e : eb)  { e.mask |= 2; }
        for (Segment e : eab) { e.mask |= 4; }

        boolean hasNotTwice = false;
        boolean has3 = false;

        for (List<Segment> l : Arrays.asList(ea, eb, eab)) {
            for (Segment s : l) {
                hasNotTwice |= (Integer.bitCount(s.mask) != 2);
                has3 |= (s.mask & 3) == 3;
            }
        }

        if (!has3) {
            //A and B have no common boundary points except for, probably, common vertices
            //This means they are either disjoint or one inside another.
            //The latter means quitIntersect()

            if (isInside(ea.get(0).source, ea.get(0).target, 1, eb) ||
                isInside(eb.get(0).source, eb.get(0).target, 0, ea)) {
                quitIntersect();
            }
        }

        if (hasNotTwice || sqA + sqB != sqAB) {
            quitNotUnion();
        }

        quitOk();
    }

    static boolean isInside(Point p, Point q, int tag, List<Segment> segs) {
        int sum = 0;
        p = new Point(p.x + q.x, p.y + q.y);
        for (Segment ss : segs) {
            Segment s = new Segment(new Point(ss.source.x * 2, ss.source.y * 2), new Point(ss.target.x * 2, ss.target.y * 2));
            System.arraycopy(ss.positive, 0, s.positive, 0, ss.positive.length);
            Point src = s.positive[tag] ? s.source : s.target;
            Point trg = s.positive[tag] ? s.target : s.source;
            if (src.x == p.x && trg.x == p.x) {
                //ignore
            } else {
                //if segment is above
                if (p.vmulAround(s.source, s.target) < 0 && s.source.x <= p.x && p.x <= s.target.x) {
                    int add;
                    if (p.vmulAround(src, trg) < 0) {
                        //left to right
                        add = 2;
                    } else {
                        //right to left
                        add = -2;
                    }
                    if (src.x == p.x || trg.x == p.x) {
                        add /= 2;
                    }
                    sum += add;
                }
            }
        }
        return sum != 0;
    }

    static void fillMaps(List<Segment> a, Set<Point> points, int tag) {
        for (Segment s : a) {
            Point src = s.source;
            Point trg = s.target;
            points.add(src);
            points.add(trg);
            DCELEdge e = s.ref;
            if (e == null) {
                e = s.ref = new DCELEdge(src, trg);
            }
            if (s.positive[tag]) {
                e.mask |= 1 << tag;
            } else {
                e.twin.mask |= 1 << tag;
            }
            src.incident.add(e);
            trg.incident.add(e.twin);
        }
    }

    static boolean checkSquareIntersection(List<Segment> a, List<Segment> b) {
        Set<Point> points = new HashSet<Point>();
        fillMaps(a, points, 0);
        fillMaps(b, points, 1);

        for (final Point pt : points) {
            List<DCELEdge> inc = pt.incident;
            Collections.sort(inc, new Comparator<DCELEdge>() {
                public int compare(DCELEdge l, DCELEdge r) {
                    Point lp = l.target;
                    Point rp = r.target;
                    int lh = Integer.signum(pt.compareTo(lp));
                    int rh = Integer.signum(pt.compareTo(rp));
                    if (lh != rh) {
                        return lh;
                    } else {
                        int vmul = Long.signum(pt.vmulAround(lp, rp));
                        if (vmul != 0) {
                            return -vmul;
                        } else {
                            if (l == r) {
                                return 0;
                            }
                            throw new AssertionError(l + " vs " + r);
                        }
                    }
                }
            });

            int newSize = 0;
            for (int i = 0; i < inc.size(); ++i) {
                if (i == 0 || inc.get(i) != inc.get(i - 1)) {
                    inc.set(newSize++, inc.get(i));
                }
            }
            while (inc.size() > newSize) {
                inc.remove(inc.size() - 1);
            }

            for (int i = 0, sz = pt.incident.size(); i < sz; ++i) {
                DCELEdge curr = pt.incident.get(i);
                DCELEdge next = pt.incident.get((i + 1) % sz);
                if (next.twin.next != null) throw new AssertionError(pt + ", curr = " + curr + ", next = " + next + ": next.twin.next was " + next.twin.next);
                if (curr.prev != null) throw new AssertionError(pt + ", curr = " + curr + ", next = " + next + ": curr.prev was " + curr.prev);
                next.twin.next = curr;
                curr.prev = next.twin;
            }
        }

        DCELEdge[] tmp = new DCELEdge[2];
        for (List<Segment> ls : Arrays.asList(a, b)) {
            for (Segment z : ls) {
                tmp[0] = z.ref;
                tmp[1] = z.ref.twin;
                for (DCELEdge e : tmp) {
                    int masks = 0;
                    while (!e.visited) {
                        e.visited = true;
                        masks |= e.mask;
                        e = e.next;
                    }
                    if (masks == 3) {
                        return false;
                    }
                }
            }
        }
        return true;
    }

    static Point[] subtract(Point[] from, Point[] what) {
        Point[] rv = new Point[from.length - what.length];
        for (int i = 0, j = 0, k = 0; i < from.length; ++i) {
            if (j < what.length && from[i] == what[j]) {
                ++j;
            } else {
                rv[k++] = from[i];
            }
        }
        return rv;
    }

    static long square(Point[] a) {
        long square = 0;
        Point zero = new Point(0, 0);
        int n = a.length;
        for (int i = 0; i < n; ++i) {
            square += zero.vmulAround(a[i], a[(i + 1) % n]);
        }
        return square;
    }

    static void throwIfCoinciding(Point[] a) {
        Set<Point> s = new HashSet<Point>(Arrays.asList(a));
        if (s.size() != a.length) {
            throw new AssertionError(Arrays.toString(a) + " " + s);
        }
    }

    static Segment[] segmentsFromPoints(Point[] a, int tag, boolean positivelyOriented) {
        if (a.length <= 1) {
            return new Segment[0];
        } else if (a.length == 2) {
            return new Segment[] { Segment.make(a[0], a[1]) };
        }
        int n = a.length;
        Segment[] rv = new Segment[n];
        for (int i = 0; i < n; ++i) {
            rv[i] = Segment.make(a[i], a[(i + 1) % n]);
            rv[i].positive[tag] = positivelyOriented == (rv[i].source == a[i]);
        }
        return rv;
    }

    public static Point[] readPoints(BufferedReader in) throws IOException {
        int n = Integer.parseInt(in.readLine());
        Point[] rv = new Point[n];
        for (int i = 0; i < n; ++i) {
            String ln = in.readLine();
            int ws = ln.indexOf(' ');
            rv[i] = Point.make(Integer.parseInt(ln.substring(0, ws)),
                               Integer.parseInt(ln.substring(ws + 1)));
        }
        return rv;
    }

    static int pointCount = 0;
    static int splitCount = 0;
    static int segmentsOn = 0;
    static int segmentsOff = 0;
    static int sweepSize = 0;

    public static List<Segment> subdivide(Segment[] segments, Point[] points, Point[] deadPoints) {
        try {
            Event[] events = new Event[2 * segments.length + points.length + deadPoints.length];
            int eventCount = 0;
            for (Segment s : segments) {
                events[eventCount++] = new Event(s, false);
                events[eventCount++] = new Event(s, true);
            }
            for (Point p : points) {
                events[eventCount++] = new Event(p, false);
            }
            for (Point p : deadPoints) {
                events[eventCount++] = new Event(p, true);
            }
            Arrays.sort(events);

            for (Segment s : segments) {
                s.parent = s.child = s;
            }

            TreeSet<Segment> sweep = new TreeSet<Segment>(CMPS);
            List<Segment> result = new ArrayList<Segment>(segments.length + points.length);

            for (Event e : events) {
                sweepSize = Math.max(sweepSize, sweep.size());
                if (e.segment == null) {
                    ++pointCount;
                    Segment test = new Segment(e.point, e.point);
                    Segment res = sweep.floor(test);
                    if (res != null && e.point.vmulAround(res.source, res.target) == 0 && res.source != e.point && res.target != e.point) {
                        if (e.deadOnSplit) {
                            throw INTERSECTION;
                        }
                        ++splitCount;
                        sweep.remove(res);
                        Segment parent = res.parent;
                        Segment l = Segment.make(res.source, e.point);
                        Segment r = Segment.make(e.point, res.target);
                        for (int i = 0; i < parent.positive.length; ++i) {
                            if (parent.positive[i] != null) {
                                l.positive[i] = parent.positive[i];
                                r.positive[i] = parent.positive[i];
                            }
                        }
                        result.add(l);
                        parent.child = r;
                        l.parent = parent;
                        r.parent = parent;
                        sweep.add(r);
                    }
                } else if (e.segment.source == e.point) {
                    ++segmentsOn;
                    sweep.add(e.segment);
                    Segment l = sweep.lower(e.segment);
                    Segment r = sweep.higher(e.segment);
                    if (l != null) {
                        CMPS.compare(e.segment, l);
                    }
                    if (r != null) {
                        CMPS.compare(e.segment, r);
                    }
                } else if (e.segment.target == e.point) {
                    ++segmentsOff;
                    Segment real = e.segment.child;
                    if (!sweep.remove(real)) {
                        throw new AssertionError(real + "; " + sweep);
                    }
                    result.add(real);
                    Segment l = sweep.lower(real);
                    Segment r = sweep.higher(real);
                    if (l != null && r != null) {
                        CMPS.compare(l, r);
                    }
                }
            }
            return result;
        } catch (RuntimeException ex) {
            if (ex == INTERSECTION) {
                return null;
            } else {
                throw ex;
            }
        }
    }

    public static class Point implements Comparable<Point> {
        public final int x, y;
        final List<DCELEdge> incident = new ArrayList<DCELEdge>(2);

        public long vmulAround(Point l, Point r) {
            return (long) (l.x - x) * (r.y - y) - (long) (l.y - y) * (r.x - x);
        }

        public int compareTo(Point that) {
            return x == that.x ? y - that.y : x - that.x;
        }

        public boolean equals(Object o) {
            if (o != null && o.getClass() == Point.class) {
                Point that = (Point) (o);
                return x == that.x && y == that.y;
            } else {
                return false;
            }
        }

        public int hashCode() {
            return x * 31 + y * 366239;
        }

        public String toString() {
            return "(" + x + ", " + y + ")";
        }

        private Point(int x, int y) {
            this.x = x;
            this.y = y;
        }

        public static Point make(int x, int y) {
            Point key = new Point(x, y);
            Point value = uniq.get(key);
            if (value == null) {
                uniq.put(key, value = key);
            }
            return value;
        }

        public static Point[] all() {
            return uniq.keySet().toArray(new Point[uniq.size()]);
        }

        private static Map<Point, Point> uniq = new HashMap<Point, Point>();
    }

    public static class Segment {
        public final Point source, target;
        public int mask = 0;
        public Boolean[] positive = new Boolean[3];

        public DCELEdge ref = null;
        public Segment parent = this;
        public Segment child = this;

        private Segment(Point a, Point b) {
            if (a.compareTo(b) <= 0) {
                this.source = a;
                this.target = b;
            } else {
                this.source = b;
                this.target = a;
            }
        }

        public int hashCode() {
            return source.hashCode() * 31 + target.hashCode() * 23621;
        }

        public boolean equals(Object o) {
            if (o != null && o.getClass() == Segment.class) {
                Segment that = (Segment) (o);
                return source == that.source && target == that.target;
            } else {
                return false;
            }
        }

        public String toString() {
            return source + "--" + target;
        }

        public static Segment make(Point a, Point b) {
            Segment key = new Segment(a, b);
            Segment value = uniq.get(key);
            if (value == null) {
                uniq.put(key, value = key);
            }
            return value;
        }

        private static Map<Segment, Segment> uniq = new HashMap<Segment, Segment>();
        static int allCount = 0;
    }

    public static class Event implements Comparable<Event> {
        public final Segment segment;
        public final Point point;
        private final int priority;
        public final boolean deadOnSplit;

        public Event(Segment segment, boolean start) {
            this.segment = segment;
            this.point = start ? segment.source : segment.target;
            this.priority = start ? 1 : -1;
            deadOnSplit = false;
        }

        public Event(Point single, boolean dead) {
            this.segment = null;
            this.point = single;
            this.priority = 0;
            this.deadOnSplit = dead;
        }

        public int compareTo(Event that) {
            int diff = point.compareTo(that.point);
            return (diff == 0) ? priority - that.priority : diff;
        }
    }

    public static final RuntimeException INTERSECTION = new RuntimeException("Intersection");

    public static Comparator<Segment> CMPS = new Comparator<Segment>() {
        public int compare(Segment l, Segment r) {
            if (l == r) {
                return 0;
            }
            int ls = Long.signum(l.source.vmulAround(r.source, r.target));
            int lt = Long.signum(l.target.vmulAround(r.source, r.target));
            if (ls * lt >= 0 && ls + lt != 0) {
                return +(ls + lt);
            }
            int rs = Long.signum(r.source.vmulAround(l.source, l.target));
            int rt = Long.signum(r.target.vmulAround(l.source, l.target));
            if (rs * rt >= 0 && rs + rt != 0) {
                return -(rs + rt);
            }
            if (l.source == l.target || r.source == r.target) {
                return 0;
            }
            throw INTERSECTION;
        }
    };

    static class DCELEdge {
        DCELEdge twin, prev, next;
        Point source, target;

        int mask = 0;
        boolean visited = false;

        DCELEdge(DCELEdge twin) {
            this.twin = twin;
            this.source = twin.target;
            this.target = twin.source;
        }

        DCELEdge(Point source, Point target) {
            this.source = source;
            this.target = target;
            this.twin = new DCELEdge(this);
        }
        public String toString() { return source + "->" + target; }
    }
}

