/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem K. Kingdom Reunion                                     */
/*                                                                */
/* Original idea         Maxim Buzdalov                           */
/* Problem statement     Maxim Buzdalov                           */
/* Test set              Maxim Buzdalov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

/**
 * Solution for NEERC'2012 Problem K: Kingdom Reunion
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class kingdom_re {
    public static final int MAX_N = 10_000;
    public static final int MAX_ABS_XY = 100_000;

    public static final String A = "Aastria";
    public static final String B = "Abstria";
    public static final String C = "Aabstria";
    public static final String ERR = " is not a polygon";

    private static final boolean DEBUG = false;
    private static final boolean VALIDATE = false;

    enum Answer {
        A_ERR(A + ERR),
        B_ERR(B + ERR),
        C_ERR(C + ERR),
        INTERSECT(A + " and " + B + " intersect"),
        NOT_EQUAL("The union of " + A + " and " + B + " is not equal to " + C),
        OK("OK");

        final String s;

        Answer(String s) {
            this.s = s;
        }

        @Override
        public String toString() {
            return s;
        }
    }

    public static void main(String[] args) throws Exception {
        new kingdom_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    private static long det(long a11, long a12, long a21, long a22) {
        return a11 * a22 - a12 * a21;
    }

    private static final int INS_NO = 0;
    private static final int INS_AT = 1;
    private static final int INS_IN = 2;

    private static int inSegment(long a, int a1, int a2) {
        if (a == a1 || a == a2)
            return INS_AT;
        if (a1 > a2) {
            int t = a1;
            a1 = a2;
            a2 = t;
        }
        return a > a1 && a < a2 ? INS_IN : INS_NO;
    }

    static class Pt implements Comparable<Pt> {
        final int id;
        final int x;
        final int y;

        Pt(int id, Scanner in) {
            this.id = id;
            x = in.nextInt();
            y = in.nextInt();
            assert Math.abs(x) <= MAX_ABS_XY && Math.abs(y) <= MAX_ABS_XY;
            in.nextLine();
        }

        @Override
        public int compareTo(Pt o) {
            int d = x - o.x;
            if (d != 0)
                return d;
            return y - o.y;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (!(o instanceof Pt)) return false;
            Pt pt = (Pt) o;
            return x == pt.x && y == pt.y;
        }

        @Override
        public int hashCode() {
            return 31 * x + y;
        }

        @Override
        public String toString() {
            return "#" + id + "(" + x + "," + y + ")";
        }

        public int in(Seg seg) {
            if (equals(seg.a) || equals(seg.b))
                return INS_AT;
            if (inSegment(x, seg.a.x, seg.b.x) == INS_NO || inSegment(y, seg.a.y, seg.b.y) == INS_NO)
                return INS_NO;
            return det(x - seg.a.x, y - seg.a.y, seg.dx(), seg.dy()) == 0 ? INS_IN : INS_NO;
        }
    }

    static class Poly {
        final int pid;
        final int n;
        final Pt[] pts;
        final APt[] apts;

        Poly(int pid, Scanner in) {
            this.pid = pid;
            n = in.nextInt();
            assert n >= 1 && n <= MAX_N;
            in.nextLine();
            pts = new Pt[n];
            Set<Pt> unique = new HashSet<>();
            for (int i = 0; i < n; i++) {
                pts[i] = new Pt(i, in);
                assert unique.add(pts[i]);
            }
            apts = new APt[n];
            for (int i = 0; i < n; i++) {
                Pt prev = pts[(i + n - 1) % n];
                Pt pt = pts[i];
                Pt next = pts[(i + 1) % n];
                apts[i] = new APt(pid, pt, new Seg(pid, pt, prev), new Seg(pid, pt, next));
            }
        }
    }

    Poly a;
    Poly b;
    Poly c;

    void read() throws Exception {
        Scanner in = new Scanner(new File("kingdom.in"));
        a = new Poly(0, in);
        b = new Poly(1, in);
        c = new Poly(2, in);
        in.close();
    }

    static int curX; // segment comparison x. Compare segs at curX+eps
    static int curY; // segment comparison y. Compare vertical segs at curY
    static int curEps; // eps for comparison at same x. compare to the right with curEps = 1, to the left with curEps = -1

    private static final int DIR_OUT_IN = 1;
    private static final int DIR_IN_OUT = 2;

    static class Seg implements Comparable<Seg> {
        final int pid; // == poly.id
        // a < b
        final Pt a;
        final Pt b;
        final boolean sweepAdd; // if false -- remove
        int dir; // init when added to sweep line on first pass (checking each one individually)

        Seg(int pid, Pt cur, Pt other) {
            this.pid = pid;
            if (cur.compareTo(other) < 0) {
                this.a = cur;
                this.b = other;
                this.sweepAdd = true;
            } else {
                this.a = other;
                this.b = cur;
                this.sweepAdd = false;
            }
        }

        // y@x = p(x) / dx()
        long p(long x) {
            return (long) a.y * dx() + (x - a.x) * dy();
        }

        long dx() {
            return b.x - a.x;
        }

        long dy() {
            return b.y - a.y;
        }

        public long det() {
            return kingdom_re.det(a.x, a.y, b.x, b.y);
        }

        // uses static curX, curY, and curEps
        @Override
        public int compareTo(Seg o) {
            int res = compareSeg(o, curX, curY, curEps);
            if (res != 0)
                return res;
            return pid - o.pid;
        }

        // does not take pid into account when comparing!
        public int compareSeg(Seg o, int curX, int curY, int curEps) {
            // p() / dx() ? o.p() / o.dx()
            long p1 = p(curX);
            long q1 = dx();
            if (q1 == 0) {
                // vertical
                p1 = curY;
                q1 = 1;
            }
            long p2 = o.p(curX);
            long q2 = o.dx();
            if (q2 == 0) {
                // vertical
                p2 = curY;
                q2 = 1;
            }
            assert q1 > 0 && q2 > 0;
            // p1 / q1 ? p2 / q2
            // order by Y first
            int res = Long.compare(p1 * q2, p2 * q1);
            if (res != 0)
                return res;
            // same Y -- order by angle, coming from eps direction
            // figure out effective eps based on curY
            int eps = curEps;
            // y == p1 / q1 == p2 / q2 ? curY
            res = Long.compare(p1, q1 * curY);
            if (res < 0)
                eps = 1; // to the left of sweep line
            if (res > 0)
                eps = -1; // to the right of sweep line
            // otherwise when y == curY -- eps depends on operation
            // actual comparison by angle
            // when everything truly equal -- compare by id
            if (dx() == 0) {
                return o.dx() == 0 ? 0 : eps;
            } else {
                // dx() != 0
                if (o.dx() == 0)
                    return -eps;
                else {
                    // dx() != 0 && o.dx() != 0, but same point, use eps
                    // dy() * curEps / dx() ? o.dy() * curEps / o.dx()
                    return Long.compare(dy() * o.dx(), o.dy() * dx()) * eps;
                }
            }
        }

        @Override
        public String toString() {
            return "[" + pid + "] " + a + "->" + b + (dir == 0 ? "" : " dir=" + dir);
        }

        public double computeY() {
            double p = p(curX);
            long q = dx();
            if (q == 0) {
                // vertical
                p = curY;
                q = 1;
            }
            return p / q;
        }
    }

    static class APt implements Comparable<APt> { // attributed points
        final int pid;
        final Pt pt;
        final Seg u;
        final Seg v;

        APt(int pid, Pt pt, Seg u, Seg v) {
            this.pid = pid;
            this.pt = pt;
            // make sure that segments added left-to-right to the sweep line
            // this gets us to compute correct Seg.dir for each added segment
            if (u.compareSeg(v, pt.x, pt.y, 1) < 0) {
                this.u = u;
                this.v = v;
            } else {
                this.u = v;
                this.v = u;
            }
        }

        @Override
        public int compareTo(APt o) {
            return pt.compareTo(o.pt);
        }

        @Override
        public String toString() {
            return "[" + pid + "] " + pt.toString();
        }

        public boolean isAtCurXY() {
            return pt.x == curX && pt.y == curY;
        }
    }

    // Node for AVL Tree
    static class Node {
        final Seg key;
        Node parent;
        Node left;
        Node right;
        int h;

        public Node(Seg key) {
            this.key = key;
        }

        public Node first() {
            Node cur = this;
            while (cur.left != null)
                cur = cur.left;
            return cur;
        }

        public Node last() {
            Node cur = this;
            while (cur.right != null)
                cur = cur.right;
            return cur;
        }

        public Node prev() {
            if (left != null)
                return left.last();
            Node cur = this;
            while (true) {
                if (cur.parent == null)
                    return null;
                if (cur.parent.right == cur)
                    return cur.parent;
                cur = cur.parent;
            }
        }

        public Node next() {
            if (right != null)
                return right.first();
            Node cur = this;
            while (true) {
                if (cur.parent == null)
                    return null;
                if (cur.parent.left == cur)
                    return cur.parent;
                cur = cur.parent;
            }
        }

        public void update() {
            h = Math.max(h(left), h(right));
        }

        public int bal() {
            return h(left) - h(right);
        }

        private static int h(Node cur) {
            return cur == null ? 0 : cur.h + 1;
        }

        @Override
        public String toString() {
            return key.toString();
        }
    }

    // Simple AVL Tree
    static class Tree {
        Node root;

        public Node find(Seg s) {
            Node cur = root;
            while (cur != null) {
                int side = s.compareTo(cur.key);
                if (side < 0)
                    cur = cur.left;
                else if (side > 0)
                    cur = cur.right;
                else
                    return cur;
            }
            return null;
        }

        // return null is this seg is already in tree
        public Node add(Seg s) {
            Node node = new Node(s);
            if (root == null) {
                root = node;
                return node;
            }
            // find
            Node cur = root;
            while (true) {
                int side = s.compareTo(cur.key);
                Node next;
                if (side < 0) {
                    next = cur.left;
                    if (next == null) {
                        cur.left = node;
                        break;
                    }

                } else if (side > 0) {
                    next = cur.right;
                    if (next == null) {
                        cur.right = node;
                        break;
                    }
                } else
                    return null; // found in tree!
                cur = next;
            }
            node.parent = cur;
            cur.update();
            rebalance(cur);
            return node;
        }

        public void remove(Node cur) {
            if (cur.left == null) {
                relinkParent(cur.parent, cur, cur.right);
                rebalance(cur.parent);
                return;
            }
            if (cur.right == null) {
                relinkParent(cur.parent, cur, cur.left);
                rebalance(cur.parent);
                return;
            }
            // cur.left != null && cur.right != null
            Node node = cur.left.last();
            assert node.right == null;
            Node sub = node.left;
            node.left = cur.left;
            cur.left.parent = node;
            node.right = cur.right;
            cur.right.parent = node;
            relinkParent(node.parent, node, sub);
            relinkParent(cur.parent, cur, node);
            rebalance(sub);
        }

        private void rebalance(Node cur) {
            while (cur != null) {
                int bal = cur.bal();
                if (bal > 1) {
                    if (cur.left.bal() < 0)
                        rotateLeft(cur.left);
                    cur = rotateRight(cur);
                }
                else if (bal < -1) {
                    if (cur.right.bal() > 0)
                        rotateRight(cur.right);
                    cur = rotateLeft(cur);
                }
                cur.update();
                cur = cur.parent;
            }
        }

        private Node rotateRight(Node cur) {
            Node parent = cur.parent;
            Node next = cur.left;
            Node b = next.right;
            cur.left = b;
            if (b != null)
                b.parent = cur;
            next.right = cur;
            cur.parent = next;
            relinkParent(parent, cur, next);
            cur.update();
            next.update();
            return next;
        }

        private Node rotateLeft(Node cur) {
            Node parent = cur.parent;
            Node next = cur.right;
            Node b = next.left;
            cur.right = b;
            if (b != null)
                b.parent = cur;
            next.left = cur;
            cur.parent = next;
            relinkParent(parent, cur, next);
            cur.update();
            next.update();
            return next;
        }

        public boolean isEmpty() {
            return root == null;
        }

        public List<Seg> keySet() {
            List<Seg> result = new ArrayList<>();
            if (root != null) {
                Node cur = root.first();
                do {
                    result.add(cur.key);
                    cur = cur.next();
                 } while (cur != null);
            }
            return result;
        }

        private void relinkParent(Node parent, Node prevChild, Node newChild) {
            if (parent != null) {
                if (parent.left == prevChild)
                    parent.left = newChild;
                else if (parent.right == prevChild)
                    parent.right = newChild;
                else
                    throw new AssertionError("broken parent link");
            } else {
                assert root == prevChild;
                root = newChild;
            }
            if (newChild != null)
                newChild.parent = parent;
        }
    }

    Answer ans;
    boolean segmentsIntersect;

    List<APt> pts;
    Tree sw;

    void solve() {
        if (!checkPoly(a))
            ans = Answer.A_ERR;
        else if (!checkPoly(b))
            ans = Answer.B_ERR;
        else if (!checkPoly(c))
            ans = Answer.C_ERR;
        else {
            if (!checkIntersect())
                ans = Answer.INTERSECT;
            else if (!checkEqual())
                ans = Answer.NOT_EQUAL;
            else
                ans = Answer.OK;
        }
    }

    private void initSweep(Poly... ps) {
        pts = new ArrayList<>();
        for (Poly p : ps)
            for (APt apt : p.apts)
                pts.add(apt);
        Collections.sort(pts);
        sw = new Tree();
        segmentsIntersect = false;
        curX = Integer.MIN_VALUE;
        curY = Integer.MIN_VALUE;
    }

    // moves sweeping line to the point
    private void sweepAt(APt pt) {
        if (DEBUG)
            System.out.println("------ sweeping " + pt);
        int x = pt.pt.x;
        int y = pt.pt.y;
        curX = x;
        curY = y;
    }

    private boolean checkPoly(Poly poly) {
        if (DEBUG)
            System.out.println("========= Checking polyline [" + poly.pid + "]");
        if (poly.n < 3) {
            if (DEBUG)
                System.out.println("n is too small");
            return false;
        }
        initSweep(poly);
        for (APt pt : pts) {
            sweepAt(pt);
            curEps = -1; // has not processed new point yet
            if (VALIDATE)
                validateSW();
            // remove segments
            removeNodes.clear();
            checkRemove(pt);
            for (Node node : removeNodes) {
                checkIntersection(node.prev(), node.next(), false);
                if (segmentsIntersect)
                    return false;
                sw.remove(node);
            }
            // add segments
            addedNodes.clear();
            curEps = 1; // now sweep line has moved over
            checkAdd(pt);
            if (segmentsIntersect)
                return false;
            // intersect added nodes with neighbours
            for (Node node : addedNodes) {
                Seg s = node.key;
                Node left = node.prev();
                Node right = node.next();
                checkIntersection(left, node, false);
                checkIntersection(node, right, false);
                if (segmentsIntersect)
                    return false;
                if (left == null)
                    s.dir = DIR_OUT_IN;
                else
                    s.dir = DIR_IN_OUT + DIR_OUT_IN - left.key.dir;
            }
        }
        assert sw.isEmpty();
        return true;
    }

    private boolean checkIntersect() {
        if (DEBUG)
            System.out.println("========= Checking intersection");
        initSweep(a, b);
        for (int i = 0; i < pts.size();) {
            APt pt = pts.get(i);
            sweepAt(pt);
            curEps = -1; // has not processed new point yet
            if (VALIDATE)
                validateSW();
            // collect other (up to 2 pts at curX, curY coordinates)
            int j = i + 1;
            while (j < pts.size() && pts.get(j).isAtCurXY())
                j++;
            // remove all points in group
            removeNodes.clear();
            for (int k = i; k < j; k++)
                checkRemove(pts.get(k));
            for (Node node : removeNodes) {
                checkIntersection(getLeft(node, 0), getRight(node, 1), true);
                checkIntersection(getLeft(node, 1), getRight(node, 0), true);
                if (segmentsIntersect)
                    return false;
                sw.remove(node);
            }
            // add all points in group
            addedNodes.clear();
            curEps = 1; // now sweep line has moved over
            for (int k = i; k < j; k++)
                checkAdd(pts.get(k));
            // intersect added nodes
            for (Node node : addedNodes) {
                Seg s = node.key;
                if (s.dir == DIR_IN_OUT) {
                    if (isLeftIn(node, 1 - s.pid)) {
                        if (DEBUG) {
                            System.out.println("sw: " + sw.keySet());
                            System.out.println("Insides intersect to the left of " + s);
                        }
                        return false;
                    }
                } else {
                    if (isRightIn(node, 1 - s.pid)) {
                        if (DEBUG) {
                            System.out.println("sw: " + sw.keySet());
                            System.out.println("Insides intersect to the right of " + s);
                        }
                        return false;
                    }
                }
                checkIntersection(getLeft(node, 1 - s.pid), node, true);
                checkIntersection(node, getRight(node, 1 - s.pid), true);
                if (segmentsIntersect)
                    return false;
            }
            i = j; // next group of points
        }
        assert sw.isEmpty();
        return true;
    }

    private boolean checkEqual() {
        if (DEBUG)
            System.out.println("========= Checking union equality");
        initSweep(a, b, c);
        for (int i = 0; i < pts.size();) {
            APt pt = pts.get(i);
            sweepAt(pt);
            curEps = -1; // has not processed new point yet
            if (VALIDATE)
                validateSW();
            // collect other (up to 3 pts at curX, curY coordinates)
            int j = i + 1;
            while (j < pts.size() && pts.get(j).isAtCurXY())
                j++;
            // remove all points in group
            removeNodes.clear();
            for (int k = i; k < j; k++)
                checkRemove(pts.get(k));
            for (Node node : removeNodes) {
                sw.remove(node);
            }
            // add all points in group
            addedNodes.clear();
            curEps = 1; // now sweep line has moved over
            for (int k = i; k < j; k++)
                checkAdd(pts.get(k));
            // check union
            for (Node node : addedNodes) {
                Seg s = node.key;
                if (s.pid == 2) {
                    if (!hasDir(node, 0, s.dir) && !hasDir(node, 1, s.dir)) {
                        if (DEBUG) {
                            System.out.println("sw: " + sw.keySet());
                            System.out.println("Does not transition properly at " + s);
                        }
                        return false;
                    }
                } else {
                    // s.pid = 0 or 1
                    if (!hasDir(node, 1 - s.pid, DIR_IN_OUT + DIR_OUT_IN - s.dir) && !hasDir(node, 2, s.dir)) {
                        if (DEBUG) {
                            System.out.println("sw: " + sw.keySet());
                            System.out.println("Does not transition properly at " + s);
                        }
                        return false;
                    }
                }
            }
            i = j; // next group of points
        }
        assert sw.isEmpty();
        return true;
    }

    private void validateSW() {
        // validate
        System.out.println("sw: " + sw.keySet());
        Seg t = null;
        for (Seg s : sw.keySet()) {
            if (t != null)
                assert t.compareTo(s) < 0 : String.format("%s ? %s compares as %d; curX=%d; curY=%d, y1=%.6f; y2=%.6f",
                        t, s, t.compareTo(s), curX, curY, t.computeY(), s.computeY());
            t = s;
        }
    }

    private void checkRemove(APt pt) {
        checkRemove(pt.u);
        checkRemove(pt.v);
    }

    List<Node> removeNodes = new ArrayList<>();

    private void checkRemove(Seg s) {
        if (s.sweepAdd)
            return; // skip -- should be added
        if (DEBUG)
            System.out.println("... removing " + s);
        Node node = sw.find(s);
        assert node != null;
        Seg o = node.key;
        assert o.a == s.a && o.b == s.b;
        removeNodes.add(node);
    }

    private void checkAdd(APt pt) {
        checkAdd(pt.u);
        checkAdd(pt.v);
    }

    List<Node> addedNodes = new ArrayList<>();

    private void checkAdd(Seg s) {
        if (!s.sweepAdd)
            return; // skip -- should be removed
        if (DEBUG)
            System.out.println("... adding " + s);
        Node node = sw.add(s);
        if (node == null) {
            if (DEBUG)
                System.out.println("Segment " + s + " is already in tree -> intersection");
            segmentsIntersect = true;
            return;
        }
        addedNodes.add(node);
    }

    // returns true if definitely pid is inside to the left of node, false == UNKNOWN
    private boolean isLeftIn(Node node, int pid) {
        Node other = getNode(node, pid);
        if (other != null)
            return other.key.dir == DIR_IN_OUT;
        Node left = getLeft(node, pid);
        if (left != null && left.key.dir == DIR_OUT_IN)
            return true;
        Node right = getRight(node, pid);
        return right != null && right.key.dir == DIR_IN_OUT;
    }

    // returns true if definitely pid is inside to the right of node, false == UNKNOWN
    private boolean isRightIn(Node node, int pid) {
        Node other = getNode(node, pid);
        if (other != null)
            return other.key.dir == DIR_OUT_IN;
        Node right = getRight(node, pid);
        if (right != null && right.key.dir == DIR_IN_OUT)
            return true;
        Node left = getLeft(node, pid);
        return left != null && left.key.dir == DIR_OUT_IN;
    }

    private boolean hasDir(Node node, int pid, int dir) {
        Node other = getNode(node, pid);
        return other != null && other.key.dir == dir;
    }

    private Node getNode(Node node, int pid) {
        Seg s = node.key;
        if (pid < s.pid) {
            Node cur = node.prev();
            while (cur != null && cur.key.compareSeg(s, curX, curY, curEps) == 0) {
                if (cur.key.pid == pid)
                    return cur;
                cur = cur.prev();
            }
        } else if (pid > s.pid) {
            Node cur = node.next();
            while (cur != null && cur.key.compareSeg(s, curX, curY, curEps) == 0) {
                if (cur.key.pid == pid)
                    return cur;
                cur = cur.next();
            }
        } else // pid == s.pid
            return node; // bingo
        return null;
    }

    private Node getLeft(Node node, int pid) {
        Seg s = node.key;
        Node left = node.prev();
        while (left != null && left.key.compareSeg(s, curX, curY, curEps) == 0)
            left = left.prev();
        if (left == null)
            return null;
        Seg leftSeg = left.key;
        do {
            if (left.key.pid == pid)
                return left; // found!!!
            left = left.prev();
        } while (left != null && left.key.compareSeg(leftSeg, curX, curY, curEps) == 0);
        return null;
    }

    private Node getRight(Node node, int pid) {
        Seg s = node.key;
        Node right = node.next();
        while (right != null && right.key.compareSeg(s, curX, curY, curEps) == 0)
            right = right.next();
        if (right == null)
            return null;
        Seg rightSeg = right.key;
        do {
            if (right.key.pid == pid)
                return right; // found!!!
            right = right.next();
        } while (right != null && right.key.compareSeg(rightSeg, curX, curY, curEps) == 0);
        return null;
    }

    // allowTouch in the second phase where one segment is allowed to touch the other and otherwise coincide.
    // end-to-end touches are always allowed in all modes.
    private void checkIntersection(Node nodeLeft, Node nodeRight, boolean allowTouch) {
        if (nodeLeft == null || nodeRight == null)
            return;
        Seg left = nodeLeft.key;
        Seg right = nodeRight.key;
        long px = intersectionPX(left, right);
        long q = intersectionQ(left, right);
        if (q == 0) {
            // parallel lines
            if (allowTouch)
                return; // always Ok in the second phase.
            if (left.a.in(right) == INS_IN || left.b.in(right) == INS_IN ||
                    right.a.in(left) == INS_IN || right.b.in(left) == INS_IN)
            {
                if (DEBUG)
                    System.out.println(left + " and " + right + " -> parallel segments intersect");
                segmentsIntersect = true;
            } // otherwise no intersection -- only allowed end-to-end touch is possible
            return;
        }
        // compute floor and ceil of x of intersection
        long xFloor = divFloor(px, q);
        long xCeil = divCeil(px, q);
        // intersection at a number between xFloor and xCeil
        if (inSegment(xFloor, left.a.x, left.b.x) != INS_NO && inSegment(xCeil, left.a.x, left.b.x) != INS_NO &&
                inSegment(xFloor, right.a.x, right.b.x) != INS_NO && inSegment(xCeil, right.a.x, right.b.x) != INS_NO)
        {
            // ok. we have a potential intersection.
            // lets do the same integer trick with y intersection point
            long py = intersectionPY(left, right);
            long yFloor = divFloor(py, q);
            long yCeil = divCeil(py, q);
            if (inSegment(yFloor, left.a.y, left.b.y) != INS_NO && inSegment(yCeil, left.a.y, left.b.y) != INS_NO &&
                    inSegment(yFloor, right.a.y, right.b.y) != INS_NO && inSegment(yCeil, right.a.y, right.b.y) != INS_NO)
            {
                // really segment intersection
                // is it an allowed end-to-end intersection?
                if (left.a.equals(right.a) || left.a.equals(right.b) ||
                        left.b.equals(right.a) || left.b.equals(right.b)) {
                    // only end-to-end which is allowed
                    return;
                }
                // check if one just touches the other
                if (allowTouch && (left.a.in(right) != INS_NO || left.b.in(right) != INS_NO ||
                        right.a.in(left) != INS_NO || right.b.in(left) != INS_NO))
                {
                    return; // ok. allowed touch
                }
                if (DEBUG)
                    System.out.println(left + " and " + right + " -> intersect");
                segmentsIntersect = true;
            }
        }
    }

    private long divFloor(long p, long q) {
        int sign = Long.signum(p) * Long.signum(q);
        long ap = Math.abs(p);
        long aq = Math.abs(q);
        return sign >= 0 ? ap / aq : -((ap + aq - 1) / aq);
    }

    private long divCeil(long p, long q) {
        int sign = Long.signum(p) * Long.signum(q);
        long ap = Math.abs(p);
        long aq = Math.abs(q);
        return sign >= 0 ? (ap + aq - 1) / aq : - ap / aq;
    }

    private long intersectionPX(Seg u, Seg v) {
        return det(v.det(), u.det(), v.dx(), u.dx());
    }

    private long intersectionPY(Seg u, Seg v) {
        return det(v.det(), u.det(), v.dy(), u.dy());
    }

    private long intersectionQ(Seg u, Seg v) {
        return det(u.dx(), u.dy(), v.dx(), v.dy());
    }

    void write() throws Exception {
        if (DEBUG)
            System.out.println("Answer: " + ans);
        PrintWriter out = new PrintWriter("kingdom.out");
        out.println(ans);
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

