/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem L. Labyrinth of the Minotaur                           */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Georgiy Korneev                          */
/* Test set              Georgiy Korneev                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;

/**
 * Solution for NEERC'2012 Problem L: Labyrinth of the Minotaur
 * This solution checks correctness of the input.
 * This solution works in O(w * h * log max(w,h)) time.
 *
 * @author Roman Elizarov
 */
public class labyrinth_re {

    private static final char FREE = '.';
    private static final char BLOCK = '#';

    private static final int[] DX = { 1, 0, -1,  0 };
    private static final int[] DY = { 0, 1,  0, -1 };

    private static final int NOT_FOUND = Integer.MAX_VALUE;

    public static void main(String[] args) throws Exception {
        new labyrinth_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    int w;
    int h;
    char[][] m;

    void read() throws Exception {
        Scanner in = new Scanner(new File("labyrinth.in"));
        w = in.nextInt();
        h = in.nextInt();
        assert w >= 2 && w <= 1500;
        assert h >= 2 && h <= 1500;
        in.nextLine();
        m = new char[w][h];
        for (int y = 0; y < h; y++) {
            String line = in.next();
            assert line.length() == w;
            in.nextLine();
            for (int x = 0; x < w; x++) {
                m[x][y] = line.charAt(x);
                assert m[x][y] == FREE || m[x][y] == BLOCK;
            }
        }
        assert m[0][0] == FREE;
        assert m[w - 1][h - 1] == FREE;
        in.close();
    }

    class Sums {
        int[][] s;

        Sums(boolean[][] block) {
            s = new int[w + 1][h + 1];
            for (int x = 0; x < w; x++)
                for (int y = 0; y < h; y++)
                    if (block[x][y])
                        s[x + 1][y + 1] = 1;
            for (int x = 1; x <= w; x++)
                for (int y = 1; y <= h; y++)
                    s[x][y] += s[x][y - 1];
            for (int y = 1; y <= h; y++)
                for (int x = 1; x <= w; x++)
                    s[x][y] += s[x - 1][y];
        }

        int get(int x1, int y1, int x2, int y2) {
            return s[x2 + 1][y2 + 1] - s[x2 + 1][y1] - s[x1][y2 + 1] + s[x1][y1];
        }
    }

    Sums blocks;
    Sums left;
    Sums right;

    int ansL;
    int ansX;
    int ansY;

    void solve() {
        blocks = new Sums(doNotBlock());
        left = new Sums(visit(0, 3));
        right = new Sums(visit(1, 1));
        ansL = NOT_FOUND;
        for (int x = 0; x < w; x++)
            for (int y = 0; y < h; y++) {
                int maxLen = Math.min(w - x, h - y);
                int a = 0;
                int b = maxLen + 1;
                // (a,b] candidate interval of Ls that blocks left&right passages
                // find min len with binary search
                while (a < b - 1) {
                    int len = (a + b) / 2;
                    if (left.get(x, y, x + len - 1, y + len - 1) > 0 && right.get(x, y, x + len - 1, y + len - 1) > 0)
                        b = len;
                    else
                        a = len;
                }
                int len = b;
                if (len <= maxLen && len < ansL && blocks.get(x, y, x + len - 1, y + len - 1) == 0) {
                    ansL = len;
                    ansX = x;
                    ansY = y;
                }
            }
    }

    boolean[][] doNotBlock() {
        boolean[][] a = new boolean[w][h];
        for (int x = 0; x < w; x++)
            for (int y = 0; y < h; y++)
                if (m[x][y] == BLOCK)
                    a[x][y] = true;
        a[0][0] = true;
        a[w - 1][h - 1] = true;
        return a;
    }

    boolean[][] visit(int d, int r) {
        boolean[][] a = new boolean[w][h];
        int x = 0;
        int y = 0;
        int vc = 0;
    scan:
        while (x != w - 1 || y != h - 1) {
            a[x][y] = true;
            vc++;
            assert vc <= w * h : "cannot reach lair";
            d = (d + r) % 4;
            for (int j = 0; j < 4; j++) {
                int xx = x + DX[d];
                int yy = y + DY[d];
                if (xx >= 0 && xx < w && yy >= 0 && yy < h && m[xx][yy] == FREE) {
                    x = xx;
                    y = yy;
                    continue scan;
                }
                d = (d + r + 2) % 4;
            }
            throw new AssertionError("blocked at (" + x + "," + y + ")");
        }
        a[x][y] = true;
        return a;
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("labyrinth.out");
        if (ansL == NOT_FOUND)
            out.println("Impossible");
        else
            out.println(ansL + " " + (ansX + 1) + " " + (ansY + 1));
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

